@@ -38,23 +38,18 @@ class BabSwitcher : public KSystemTray , public babInterface{
    Q_OBJECT
 public: 
    
-   enum State {Jaguar = 0, Panther, iTunes, Tiger};
-//   enum DecoState {Jaguar = 0, Panther, Brushed}
+   enum State {Jaguar = 0, Panther, iTunes, Tiger, Milk};
 
    BabSwitcher(bab *parent=0, const char *name=0);
    ~BabSwitcher();
 
-   void toggleState();
-   void setState(int);
-   int state();
-   void setDecoState(int);
-   int decoState();
-   void start(QString name, int state, int decoState);
-   void start(QString name, int decoState);
+   void toggle();
+   void setStyle(QString);
+   QString style();
+   void setDeco(QString);
+   QString deco();
+   void start(QString name, QString settings);
    void emitStyleChanged();
-   void readState();
-   void saveDecoState();
-   void save2States();
    static QPoint *globalPos;
    
 protected:
@@ -65,16 +60,11 @@ private:
 
    int state_;
    int decoState_;
-   int oldState;
-   int oldDecoState;
    QPixmap JaguarIcon;
    QPixmap PantherIcon;
    QPixmap iTunesIcon;
    QPixmap TigerIcon;
-
-
-public slots:
-      void saveState();
+   QPixmap MilkIcon;
 };
 
 
