@@ -52,7 +52,7 @@
 static const char description[] =
     I18N_NOOP("Baghira Aqua/Brushed");
 
-static const char version[] = "0.6e";
+static const char version[] = "cvs";
 
 static KCmdLineOptions options[] =
 {
@@ -105,6 +105,52 @@ bab::bab() : KMainWindow(0,"bab",Qt::WStyle_StaysOnTop | Qt::WX11BypassWM ){
    d = QDir( QDir::homeDirPath() + "/.baghira/.bab");
    if (!d.exists())
        d.mkdir(QDir::homeDirPath() + "/.baghira/.bab");
+   FILE *file = NULL;
+   QString tmpString = QDir::homeDirPath() + "/.baghira/Jaguar";
+   if (!QFile::exists(tmpString))
+   {
+      if( (file = fopen(tmpString.latin1(), "w")) != NULL )
+      {
+         fprintf(file,"0\n0\n0\n0\n0\n1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n1\n");
+         fclose(file);
+      }
+   }
+   tmpString = QDir::homeDirPath() + "/.baghira/Panther";
+   if (!QFile::exists(tmpString))
+   {
+      if( (file = fopen(tmpString.latin1(), "w")) != NULL )
+      {
+         fprintf(file,"1\n1\n1\n1\n1\n1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n1\n");
+         fclose(file);
+      }
+   }
+   tmpString = QDir::homeDirPath() + "/.baghira/Brushed";
+   if (!QFile::exists(tmpString))
+   {
+      if( (file = fopen(tmpString.latin1(), "w")) != NULL )
+      {
+         fprintf(file,"2\n2\n1\n2\n1\n1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n0\n");
+         fclose(file);
+      }
+   }
+   tmpString = QDir::homeDirPath() + "/.baghira/Tiger";
+   if (!QFile::exists(tmpString))
+   {
+      if( (file = fopen(tmpString.latin1(), "w")) != NULL )
+      {
+         fprintf(file,"3\n3\n1\n1\n0\n1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n-1\n1\n");
+         fclose(file);
+      }
+   }
+   tmpString = QDir::homeDirPath() + "/.baghira/Milk";
+   if (!QFile::exists(tmpString))
+   {
+      if( (file = fopen(tmpString.latin1(), "w")) != NULL )
+      {
+         fprintf(file,"4\n4\n4\n4\n1\n0\n-592138\n-4930834\n-1\n-16777216\n-13009982\n-1\n-16777216\n-1116417\n1\n");
+         fclose(file);
+      }
+   }
    
    QVBox *vb = new QVBox(this);
    vb->setLineWidth(2);
@@ -117,6 +163,7 @@ bab::bab() : KMainWindow(0,"bab",Qt::WStyle_StaysOnTop | Qt::WX11BypassWM ){
    DefStyle->insertItem ( "Panther" );
    DefStyle->insertItem ( "Brushed" );
    DefStyle->insertItem ( "Tiger" );
+   DefStyle->insertItem ( "Milk" );
    cornerCheck = new QCheckBox("Round upper screen corners", vb);
    QSettings config;
    config.beginGroup("/baghira/BAB");
@@ -127,7 +174,8 @@ bab::bab() : KMainWindow(0,"bab",Qt::WStyle_StaysOnTop | Qt::WX11BypassWM ){
    QPushButton *Quit = new QPushButton("Quit BAB", vb);
    QPushButton *Close = new QPushButton("Close Menu", vb);
    vb->adjustSize();
-   bSwitcher->setState(DefStyle->currentItem());
+   bSwitcher->setStyle(DefStyle->currentText());
+   bSwitcher->setDeco(DefStyle->currentText());
    
    connect(DefStyle, SIGNAL(activated(int)), this, SLOT(saveSettings()));
    connect(cornerCheck, SIGNAL(toggled(bool)), this, SLOT(saveSettings()));
@@ -140,8 +188,10 @@ bab::bab() : KMainWindow(0,"bab",Qt::WStyle_StaysOnTop | Qt::WX11BypassWM ){
 //   show();
 }
 
-bab::~ bab(){
-   bSwitcher->setState(DefStyle->currentItem());
+bab::~ bab()
+{
+   bSwitcher->setStyle(DefStyle->currentText());
+   bSwitcher->setDeco(DefStyle->currentText());
    if (bSwitcher) delete bSwitcher;
 }
 
@@ -289,123 +339,160 @@ BabSwitcher::BabSwitcher(bab *parent, const char *name)
    PantherIcon = iLoader->loadIcon("bab_panther", KIcon::Small, 22);
    iTunesIcon = iLoader->loadIcon("bab_itunes", KIcon::Small, 22);
    TigerIcon = iLoader->loadIcon("bab_tiger", KIcon::Small, 22);
-   readState();
+   MilkIcon = iLoader->loadIcon("bab_milk", KIcon::Small, 22);
    installEventFilter(this);
 }
 
 BabSwitcher::~BabSwitcher(){
 }
 
-void BabSwitcher::toggleState(){
-   if ( state_ < Tiger )
+void BabSwitcher::toggle()
+{
+   if ( state_ < Milk )
       state_++;
    else
       state_ = Jaguar;
-   save2States();
+   decoState_ = state_;
+   QString nameString;
+   switch (state_)
+   {
+   case Jaguar:
+      nameString = "Jaguar";
+      break;
+   case Panther:
+      nameString = "Panther";
+      break;
+   case iTunes:
+      nameString = "Brushed";
+      break;
+   case Tiger:
+      nameString = "Tiger";
+      break;
+   case Milk:
+      nameString = "Milk";
+   }
+   QString tmpString = QDir::homeDirPath() + "/.baghira/" + nameString;
+   QString tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/.style";
+   remove(tmpString2.latin1());
+   symlink (tmpString.latin1(), tmpString2.latin1());
+   tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/.deco";
+   remove(tmpString2.latin1());
+   symlink (tmpString.latin1(), tmpString2.latin1());
    repaint();
 }
 
-void BabSwitcher::setState(int state){
-   state_ = state < 0 ? (State)0 : state > 3 ? (State)3 : (State)state;
-   saveState();
+void BabSwitcher::setStyle(QString style)
+{
+   if (style == "Jaguar")
+      state_ = Jaguar;
+   else if (style == "Brushed")
+      state_ = iTunes;
+   else if (style == "Tiger")
+      state_ = Tiger;
+   else if (style == "Milk")
+      state_ = Milk;
+   else
+   {
+      if (style != "Panther")
+         style = "Panther";
+      state_ = Panther;
+   }
+   QString tmpString = QDir::homeDirPath() + "/.baghira/" + style;
+   QString tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/.style";
+   remove(tmpString2.latin1());
+   symlink (tmpString.latin1(), tmpString2.latin1());
    repaint();
 }
 
-void BabSwitcher::setDecoState(int state){
-   decoState_ = state < 0 ? 0 : state > 3 ? 3 : state;
-   saveDecoState();
+void BabSwitcher::setDeco(QString deco)
+{
+   if (deco == "Jaguar")
+      decoState_ = Jaguar;
+   else if (deco == "Brushed")
+      decoState_ = iTunes;
+   else if (deco == "Tiger")
+      decoState_ = Tiger;
+   else if (deco == "Milk")
+      decoState_ = Milk;
+   else
+   {
+      if (deco != "Panther")
+         deco = "Panther";
+      decoState_ = Panther;
+   }
+   QString tmpString = QDir::homeDirPath() + "/.baghira/" + deco;
+   QString tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/.deco";
+   remove(tmpString2.latin1());
+   symlink (tmpString.latin1(), tmpString2.latin1());
 }
 
-int BabSwitcher::state(){
-   return (int)state_;
+QString BabSwitcher::style()
+{
+   switch (state_)
+   {
+   case Jaguar:
+      return "Jaguar";
+   case Panther:
+      return "Panther";
+   case iTunes:
+      return "Brushed";
+   case Tiger:
+      return "Tiger";
+   case Milk:
+      return "Milk";
+   }
 }
 
-int BabSwitcher::decoState(){
-   return decoState_;
+QString BabSwitcher::deco()
+{
+   switch (decoState_)
+   {
+   case Jaguar:
+      return "Jaguar";
+   case Panther:
+      return "Panther";
+   case iTunes:
+      return "Brushed";
+   case Tiger:
+      return "Tiger";
+   case Milk:
+      return "Milk";
+   }
 }
 
-void BabSwitcher::start(QString name, int state, int decoState){
-    if (state < 0)
-        state = 0;
-    else if (state > 3)
-        state = 3;
-    if (decoState < 0)
-        decoState = 0;
-    else if (decoState > 3)
-        decoState = 3;
-    FILE *file = NULL;
-    KProcess proc;// = new KProcess;
-    QString section; int i = 0; bool done = false;
-    if (name.contains(' ')){
-        while (!done){
-            section = name.section(' ',i,i);
-            if (i == 0)
-            {
-                QString tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + section;
-                if( (file = fopen(tmpString.latin1(), "w")) != NULL )
-                {
-                    fprintf(file,"%d\n%d\n",state, decoState);
-                    fclose(file);
-                }
-            }
-            if (!section.isEmpty())
-                proc << section;
-            else
-                done = true;
-            i++;
-        }
-    }
-    else {
-        QString tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + name;
-        if( (file = fopen(tmpString.latin1(), "w")) != NULL )
-        {
-            fprintf(file,"%d\n%d\n",state, decoState);
-            fclose(file);
-        }
-        proc << name;
-    }
-    proc.start(KProcess::DontCare);
-    proc.detach();
-}
-
-void BabSwitcher::start(QString name, int decoState){
-    if (decoState < 0)
-        decoState = 0;
-    else if (decoState > 3)
-        decoState = 3;
-    FILE *file = NULL;
-    KProcess proc;// = new KProcess;
-    QString section; int i = 0; bool done = false;
-    if (name.contains(' ')){
-        while (!done){
-            section = name.section(' ',i,i);
-            if (i == 0)
-            {
-                QString tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + section;
-                if( (file = fopen(tmpString.latin1(), "w")) != NULL )
-                {
-                    fprintf(file,"\n%d\n", decoState);
-                    fclose(file);
-                }
-            }
-            if (!section.isEmpty())
-                proc << section;
-            else
-                done = true;
-            i++;
-        }
-    }
-    else {
-        QString tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + name;
-        if( (file = fopen(tmpString.latin1(), "w")) != NULL )
-        {
-            fprintf(file,"\n%d\n", decoState);
-            fclose(file);
-        }
-        proc << name;
-    }
-    proc.start(KProcess::DontCare);
-    proc.detach();
+void BabSwitcher::start(QString name, QString settings)
+{
+   KProcess proc;
+   QString section; int i = 0; bool done = false;
+   if (name.contains(' '))
+   {
+      while (!done)
+      {
+         section = name.section(' ',i,i);
+         if (i == 0)
+         {
+            QString tmpString = QDir::homeDirPath() + "/.baghira/" + settings;
+            QString tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/" + section;
+            remove(tmpString2.latin1());
+            symlink (tmpString.latin1(), tmpString2.latin1());
+         }
+         if (!section.isEmpty())
+            proc << section;
+         else
+            done = true;
+         i++;
+      }
+   }
+   else
+   {
+      QString tmpString = QDir::homeDirPath() + "/.baghira/" + settings;
+      QString tmpString2 = QDir::homeDirPath() + "/.baghira/.bab/" + name;
+      remove(tmpString2.latin1());
+      symlink (tmpString.latin1(), tmpString2.latin1());
+      proc << name;
+   }
+   proc.start(KProcess::DontCare);
+   proc.detach();
 }
 
 void BabSwitcher::emitStyleChanged()
@@ -414,44 +501,6 @@ void BabSwitcher::emitStyleChanged()
    KIPC::sendMessageAll(KIPC::ToolbarStyleChanged);
 }
 
-void BabSwitcher::saveState(){
-   QSettings *config = new QSettings;
-   config->beginGroup("/baghira/Style");
-   config->writeEntry("Design_Default", state_ );
-   config->endGroup();
-   delete config;
-}
-
-void BabSwitcher::saveDecoState(){
-   QSettings *config = new QSettings;
-   config->beginGroup("/baghira/Deco");
-   config->writeEntry("defaultMode", decoState_);
-   config->endGroup();
-   delete config;
-}
-
-void BabSwitcher::save2States()
-{
-   QSettings *config = new QSettings;
-   config->beginGroup("/baghira/Style");
-   config->writeEntry("Design_Default", state_ );
-   config->endGroup();
-   config->beginGroup("/baghira/Deco");
-   config->writeEntry("defaultMode", state_);
-   config->endGroup();
-   delete config;
-}
-
-void BabSwitcher::readState(){
-   QSettings config;
-   config.beginGroup("/baghira/Style");
-   state_ = (State)config.readNumEntry("Design_Default", 1 );
-   config.endGroup();
-   config.beginGroup("/baghira/Deco");
-   decoState_ = config.readNumEntry("defaultMode",1);
-   config.endGroup();
-}
-
 void BabSwitcher::mousePressEvent(QMouseEvent *e){
 
   QWidget *daddy = parentWidget();
@@ -463,18 +512,12 @@ void BabSwitcher::mousePressEvent(QMouseEvent *e){
    {
    case LeftButton:
    {
-      if ( state_ < Tiger )
-         state_++;
-      else
-         state_ = Jaguar;
-      saveState();
-      repaint();
+      toggle();
       break;
    }
    case RightButton:
    default:
    {
-   // toggleMinimizeRestore();
       if ( daddy->isVisible() )
          daddy->hide();
       else
@@ -499,10 +542,12 @@ void BabSwitcher::paintEvent(QPaintEvent *ev){
       break;
    case Tiger:
       TigerIcon.isNull() ? icyApainter.fillRect(rect(), Qt::yellow) : icyApainter.drawPixmap(0, 0, TigerIcon);
+      break;
+   case Milk:
+      MilkIcon.isNull() ? icyApainter.fillRect(rect(), Qt::white) : icyApainter.drawPixmap(0, 0, MilkIcon);
    default:
       break;
    }
-//    icyApainter->flush();
    icyApainter.end();
 }
 
