@@ -29,9 +29,13 @@
 #include "help.h"
 #include "about.h"
 
-class QListBox;
+class KListView;
 class QPushButton;
 class AppSetter;
+class QTimer;
+class QCheckBox;
+class QComboBox;
+class QGroupBox;
 
 class kstyle_baghira_config: public QWidget
 {
@@ -66,14 +70,15 @@ public slots:
 
 signals:
    void changed(bool);
-   void editApp(QString&);
+   void editApp(QString, QString);
 
 protected:
    bool eventFilter( QObject* o, QEvent* e );
 
 private:
+   QString crNotes[3];
    AppSetter *appsetter;
-   QListBox *applist;
+   KListView *applist;
    QImage* tintButton(QImage &src, QColor c);
    QImage* tintBrush( QImage &img, QColor c/*, int saturation*/ );
    WId findWindow();
@@ -89,11 +94,15 @@ private:
    int sliderBrushRedValue, sliderBrushGreenValue, sliderBrushBlueValue/*, sliderBrushSaturationValue*/;
    bool loadDone;
    bool menuReplaced;
+   QTimer *timer;
+   int crCurrent;
 private slots:
+   void updateCR();
+   void showAbout();
    void editApp();
-   void addApp(QString &);
+   void addApp(QString, QString);
    void removeApp();
-   void removeApp(QString &);
+   void removeApp(QString);
    void setDesign(int);
    void menuToggled(bool);
    void enableInButtonColor(int d);
@@ -102,6 +111,8 @@ private slots:
    void buttonSaveAsAction();
    void setPresetColor(int i);
    void selectWindow();
+   void changeTooluttonHighlightColor(const QColor &);
+   void handleButtonStyles(int i);
 };
 
 class ColorDialog;
@@ -113,27 +124,32 @@ public:
    AppSetter(QWidget *parent=0, const char *name=0);
    ~AppSetter();
 public slots:
-   void show(QString &appName);
+   void show();
+   void show(QString appName, QString link);
 
 private:
    bool isEdit;
    int index_;
    int colors[8];
    QString oldName;
+   QString oldLink;
    QLineEdit *command;
+   QComboBox *link;
+   QGroupBox *box;
    QComboBox *style;
    QComboBox *deco;
    QComboBox *buttons;
    QComboBox *toolButtons;
    QComboBox *tabs;
+   QComboBox *inbutton;
    QCheckBox *scanlines;
    QCheckBox *customColors;
    QPushButton *buttonColors;
    ColorDialog *colorDialog;
 
 signals:
-   void addApp(QString &);
-   void removeApp(QString &);
+   void addApp(QString, QString);
+   void removeApp(QString);
 
 private slots:
    void save();
@@ -141,6 +157,7 @@ private slots:
    void handler(int);
    void updateColors();
    void resetColorPicker();
+   void handleButtonStyles(int i);
 };
 
 #endif
