@@ -77,35 +77,35 @@ static const int MARGIN = 6;
 //////////////////////////////////////////////////////////////////////////////
 
 bool BaghiraFactory::initialized_ = false;
-Baghira::TitlebarType BaghiraFactory::effect_[4][2];
+Baghira::TitlebarType BaghiraFactory::effect_[5][2];
 Qt::AlignmentFlags BaghiraFactory::titlealign_;
-QColor BaghiraFactory::colors_[4][ ColorTypeCount ][ 2 ];
-KPixmap BaghiraFactory::pix_[4][ PixmapTypeCount ][ 2 ][ 2 ];
-int BaghiraFactory::bordersize_[4] = {0,0,6,0};//{BorderTiny, BorderTiny, BorderVeryHuge};
-QPixmap BaghiraFactory::ButtonPixmap_[4][WindowStateAmount][ButtonTypeAmount][ButtonStateAmount][2];
+QColor BaghiraFactory::colors_[5][ ColorTypeCount ][ 2 ];
+KPixmap BaghiraFactory::pix_[5][ PixmapTypeCount ][ 2 ][ 2 ];
+int BaghiraFactory::bordersize_[5] = {0,0,6,0,0};//{BorderTiny, BorderTiny, BorderVeryHuge};
+QPixmap BaghiraFactory::ButtonPixmap_[5][WindowStateAmount][ButtonTypeAmount][ButtonStateAmount][2];
 QColor BaghiraFactory::brushedMetalColor;
 QColor BaghiraFactory::ButtonColor_[ButtonTypeAmount+1];
-QPixmap BaghiraFactory::nostalgia_[4][3][2];
+QPixmap BaghiraFactory::nostalgia_[5][3][2];
 int BaghiraFactory::contrast_;
-int BaghiraFactory::_3DImpact_[4];
-int BaghiraFactory::LineImpact_[4];
+int BaghiraFactory::_3DImpact_[5];
+int BaghiraFactory::LineImpact_[5];
 bool BaghiraFactory::bgStipple_;
 bool BaghiraFactory::comicFrame_;
 bool BaghiraFactory::addAutoSpacing_;
 bool BaghiraFactory::maxResizable_;
-bool BaghiraFactory::shape_ul[4];
-bool BaghiraFactory::shape_ur[4];
-bool BaghiraFactory::shape_ll[4];
-bool BaghiraFactory::shape_lr[4];
+bool BaghiraFactory::shape_ul[5];
+bool BaghiraFactory::shape_ur[5];
+bool BaghiraFactory::shape_ll[5];
+bool BaghiraFactory::shape_lr[5];
 bool BaghiraFactory::allowEasyClosing_;
 bool BaghiraFactory::resizeGrip_;
 uint BaghiraFactory::defaultMode_;
-bool BaghiraFactory::drawIcon_[4];
+bool BaghiraFactory::drawIcon_[5];
 bool BaghiraFactory::tintBrush_;
 bool BaghiraFactory::showTitle_;
 QColor BaghiraFactory::brushTint;
 int BaghiraFactory::minimumTitleHeight_;
-ButtonStyle BaghiraFactory::buttonStyle_[4];
+ButtonStyle BaghiraFactory::buttonStyle_[5];
 
 QBitmap BaghiraFactory::helpMask;
 QBitmap BaghiraFactory::jaguarDownMask;
@@ -118,6 +118,8 @@ QBitmap BaghiraFactory::milkMask;
 QBitmap BaghiraFactory::pantherMenuMask;
 QBitmap BaghiraFactory::pantherMask;
 QBitmap BaghiraFactory::milkDownMask;
+QBitmap BaghiraFactory::arrowUp;
+QBitmap BaghiraFactory::arrowDown;
 DeMaximizer BaghiraFactory::deMaximizer_;
 bool BaghiraFactory::fullSpec_;
 bool BaghiraFactory::noModalDeco_;
@@ -131,7 +133,7 @@ extern "C" KDecorationFactory* create_factory() {
 
 DeMaximizer::DeMaximizer() : QWidget(0, "deMaximizer", Qt::WType_TopLevel | Qt::WStyle_NoBorder | Qt::WX11BypassWM )
 {
-    client_ = NULL;
+    client_ = 0L;
     setFixedSize(16,16);
     setMouseTracking(TRUE);
     setAutoMask(TRUE);
@@ -176,11 +178,19 @@ void DeMaximizer::setPixmap(int i, QImage &image )
 }
 
 
-void DeMaximizer::setClient(BaghiraClient *client){
-    QObject::disconnect ( client_, SIGNAL(hide()), this, SLOT(hide()) );
-    client_ = client;
-    connect ( client_, SIGNAL(hide()), SLOT(hide()) );
-    setState(0);
+void DeMaximizer::setClient(BaghiraClient *client)
+{
+   if (client_)
+   {
+      QObject::disconnect ( client_, SIGNAL(hide()), this, SLOT(hide()) );
+      client_ = 0L;
+   }
+   if (client)
+   {
+      client_ = client;
+      connect ( client_, SIGNAL(hide()), SLOT(hide()) );
+      setState(0);
+   }
 //     repaint();
 }
 
@@ -291,6 +301,10 @@ BaghiraFactory::BaghiraFactory() {
     pantherMenuMask = QBitmap( 20, 15, panther_menu_bits, true );
     pantherMask = QBitmap( 14, 15, panther_bits, true );
     milkDownMask = QBitmap( 14, 15, milk_pressed_bits, true );
+   arrowUp = QBitmap( 8, 4, arrowUp_bits, true );
+   arrowUp.setMask( arrowUp );
+   arrowDown = QBitmap( 8, 4, arrowDown_bits, true );
+   arrowDown.setMask( arrowDown );
     readConfig();
     createPixmaps();
     initialized_ = true;
@@ -456,7 +470,7 @@ unsigned long BaghiraFactory::readConfig() {
                         
         // custom settings
 	
-   for (int i = 0; i < 4; i++){
+   for (int i = 0; i < 5; i++){
       
       int oldbordersize = bordersize_[i];
       bordersize_[i] = config.readNumEntry( indexedString("BorderSize",i), i == 2 ? 6 : 0 );
@@ -500,16 +514,16 @@ unsigned long BaghiraFactory::readConfig() {
 		changed |= SettingFont;
 		changed |= SettingDecoration;
 		
-   if (i < 3)
+   if (i != 3)
    {
       Baghira::TitlebarType oldeffect = effect_[i][1];
-      effect_[i][1] = ( Baghira::TitlebarType ) config.readNumEntry( indexedString("TitleEffect",i), i == 0 ? Baghira::Stipples : i == 1 ? Baghira::Gradient : Baghira::Brushed);
+      effect_[i][1] = ( Baghira::TitlebarType ) config.readNumEntry( indexedString("TitleEffect",i), i == 0 ? Baghira::Stipples : (i == 1 || i == 4) ? Baghira::Gradient : Baghira::Brushed);
    //        qWarning("%d",effect_[i]);
       if ( oldeffect != effect_[i][1] )
          changed |= SettingDecoration;
    
       oldeffect = effect_[i][0];
-      effect_[i][0] = ( Baghira::TitlebarType ) config.readNumEntry( indexedString("inactiveTitleEffect",i), i == 0 ? Baghira::Stipples : i == 1 ? Baghira::Gradient : Baghira::Brushed);
+      effect_[i][0] = ( Baghira::TitlebarType ) config.readNumEntry( indexedString("inactiveTitleEffect",i), i == 0 ? Baghira::Stipples : (i == 1 || i == 4) ? Baghira::Gradient : Baghira::Brushed);
    //        qWarning("%d",effect_[i]);
       if ( oldeffect != effect_[i][0] )
          changed |= SettingDecoration;
@@ -520,12 +534,12 @@ unsigned long BaghiraFactory::readConfig() {
          changed |= SettingDecoration;
       
       oldcolor = colors_[i][ Baghira::ColorTitleBar ][ false ];
-      colors_[i][ Baghira::ColorTitleBar ][ false ].setRgb((unsigned int)config.readNumEntry( indexedString("inactiveColor1",i), i == 0 ? QColor(204,214,230).rgb() : i == 1 ? QColor(246,242,246).rgb() : QColor(200,200,200).rgb()));
+      colors_[i][ Baghira::ColorTitleBar ][ false ].setRgb((unsigned int)config.readNumEntry( indexedString("inactiveColor1",i), i == 0 ? QColor(204,214,230).rgb() : i == 1 ? QColor(246,242,246).rgb() : i == 3 ? QColor(200,200,200).rgb() : QColor(230,230,230).rgb()));
       if ( oldcolor != colors_[i][ Baghira::ColorTitleBar ][ false ] )
          changed |= SettingColors;
       
       oldcolor = colors_[i][ Baghira::ColorTitleBlend ][ false ];
-      colors_[i][ Baghira::ColorTitleBlend ][ false ].setRgb((unsigned int)config.readNumEntry( indexedString("inactiveColor2",i), i == 0 ? QColor(194,196,211).rgb() : i == 1 ? QColor(238,238,238).rgb() : QColor(150,150,150).rgb() ));
+      colors_[i][ Baghira::ColorTitleBlend ][ false ].setRgb((unsigned int)config.readNumEntry( indexedString("inactiveColor2",i), i == 0 ? QColor(194,196,211).rgb() : i == 1 ? QColor(238,238,238).rgb() : i == 3 ? QColor(150,150,150).rgb() : QColor(250,250,250).rgb()));
       if ( oldcolor != colors_[i][ Baghira::ColorTitleBlend ][ false ] )
          changed |= SettingColors;
    }
@@ -542,12 +556,12 @@ unsigned long BaghiraFactory::readConfig() {
 		changed |= SettingDecoration;
 
    oldcolor = colors_[i][ Baghira::ColorTitleBar ][ true ];
-      colors_[i][ Baghira::ColorTitleBar ][ true ].setRgb((unsigned int)config.readNumEntry( indexedString("activeColor1",i), i == 0 ? QColor(255,255,255).rgb() : i == 1 ? QColor(238,238,238).rgb() : i == 2 ? QColor(202,202,202).rgb() : QColor(238,238,238).rgb()));
+      colors_[i][ Baghira::ColorTitleBar ][ true ].setRgb((unsigned int)config.readNumEntry( indexedString("activeColor1",i), i == 0 ? QColor(255,255,255).rgb() : i == 1 ? QColor(238,238,238).rgb() : i == 2 ? QColor(202,202,202).rgb() : i == 3 ? QColor(238,238,238).rgb() : QColor(250,250,250).rgb()));
 	if ( oldcolor != colors_[i][ Baghira::ColorTitleBar ][ true ] )
 		changed |= SettingColors;
                 
    oldcolor = colors_[i][ Baghira::ColorTitleBlend ][ true ];
-      colors_[i][ Baghira::ColorTitleBlend ][ true ].setRgb((unsigned int)config.readNumEntry( indexedString("activeColor2",i), i == 0 ? QColor(238,234,238).rgb() : i == 1 ? QColor(205,202,205).rgb() : i == 2 ? QColor(150,150,150).rgb() : QColor(211,208,211).rgb() ));
+      colors_[i][ Baghira::ColorTitleBlend ][ true ].setRgb((unsigned int)config.readNumEntry( indexedString("activeColor2",i), i == 0 ? QColor(238,234,238).rgb() : i == 1 ? QColor(205,202,205).rgb() : i == 2 ? QColor(150,150,150).rgb() : i == 3 ? QColor(211,208,211).rgb() : QColor(230,230,230).rgb()));
 	if ( oldcolor != colors_[i][ Baghira::ColorTitleBlend ][ true ] )
 		changed |= SettingColors;
                 
@@ -573,16 +587,10 @@ unsigned long BaghiraFactory::readConfig() {
 	if ( oldcolor != ButtonColor_[StickyButton] )
 		changed |= SettingColors;
 	
-	oldcolor = ButtonColor_[AboveButton];
-   ButtonColor_[AboveButton].setRgb((unsigned int)config.readNumEntry( "AboveButtonColor", QColor(74,140,242).rgb() ));
-	if ( oldcolor != ButtonColor_[AboveButton] )
+	oldcolor = ButtonColor_[AboveBelowButton];
+   ButtonColor_[AboveBelowButton].setRgb((unsigned int)config.readNumEntry( "AboveButtonColor", QColor(74,140,242).rgb() ));
+	if ( oldcolor != ButtonColor_[AboveBelowButton] )
 		changed |= SettingColors;
-	
-	oldcolor = ButtonColor_[BehindButton];
-	ButtonColor_[BehindButton].setRgb((unsigned int)config.readNumEntry( "BehindButtonColor", QColor(74,140,242).rgb() ));
-	if ( oldcolor != ButtonColor_[BehindButton] )
-		changed |= SettingColors;
-	
 	oldcolor = ButtonColor_[ShadeButton];
 	ButtonColor_[ShadeButton].setRgb((unsigned int)config.readNumEntry( "ShadeButtonColor", QColor(74,140,242).rgb() ));
 	if ( oldcolor != ButtonColor_[ShadeButton] )
@@ -886,13 +894,13 @@ void BaghiraFactory::createPixmaps() {
 	QImage tmpDeco;
 	QImage buttonImage;
 	QImage btnIcons[MenuButton];
+   btnIcons[AboveBelowButton] = QImage();
 	// load icon images - useless for nostalgia style, but i assume they'll be used at least once ;)
 	btnIcons[MinButton] = uic_findImage( "icon_minimize" );
 	btnIcons[MaxButton] = uic_findImage( "icon_maximize" );
 	btnIcons[CloseButton] = uic_findImage( "icon_close" );
 	btnIcons[StickyButton] = uic_findImage( "icon_sticky" );
-	btnIcons[AboveButton] = uic_findImage( "icon_above" );
-	btnIcons[BehindButton] = uic_findImage( "icon_behind" );
+// 	btnIcons[AboveBelowButton] = uic_findImage( "icon_above" );
 	btnIcons[ShadeButton] = uic_findImage( "icon_shade" );
 	
 	int B_3 = 0;
@@ -902,7 +910,7 @@ void BaghiraFactory::createPixmaps() {
 	int yoff = 1;
         bool brushedMode;
 	
-	for (int style = 0; style < 4; style++){
+	for (int style = 0; style < 5; style++){
         for ( int active = 0; active <= 1; ++active ) {
 		for ( int small = 0; small <= 1; ++small ) {
 			KPixmap &tbar = pix_[style][ TitleBar ][ active ][ small ];
@@ -1105,18 +1113,6 @@ void BaghiraFactory::createPixmaps() {
 								icyAPainter.end();
 								continue;
 							}
-							if (bt == AboveButton){
-								icyAPainter.drawLine(2,BUTTONSIZE/2,BUTTONSIZE/2,B_3);
-								icyAPainter.drawLine(BUTTONSIZE/2,B_3,BUTTONSIZE-3,BUTTONSIZE/2);
-								icyAPainter.end();
-								continue;
-							}
-							if (bt == BehindButton){
-								icyAPainter.drawLine(2,BUTTONSIZE/2,BUTTONSIZE/2,B_6);
-								icyAPainter.drawLine(BUTTONSIZE/2,B_6,BUTTONSIZE-3,BUTTONSIZE/2);
-								icyAPainter.end();
-								continue;
-							}
 							if (bt == ShadeButton){
 								icyAPainter.drawLine(2,B_3,BUTTONSIZE-3,B_3);
 								icyAPainter.drawLine(2,B_3+3,BUTTONSIZE-3,B_3+3);
@@ -1390,6 +1386,18 @@ void BaghiraButton::drawButton( QPainter *painter ) {
 		painter->drawPixmap( 0, 0, BaghiraFactory::ButtonPixmap( ( Baghira::WindowState ) active, type_, state() == Pressed ? Pressed : Hovered, client_->currentStyle, client_->isTool() ));
 	else
 		painter->drawPixmap( 0, 0, BaghiraFactory::ButtonPixmap( ( Baghira::WindowState ) active, type_, state() , client_->currentStyle, client_->isTool() ));
+   
+   if (type_ == Baghira::AboveBelowButton)
+   {
+      if (client_->keepAbove())
+      {
+         painter->drawPixmap((width()-8)/2,height()/2-4,BaghiraFactory::arrowUp);
+      }
+      else if (client_->keepBelow())
+      {
+         painter->drawPixmap((width()-8)/2,height()/2,BaghiraFactory::arrowDown);
+      }
+   }
 }
 
 void BaghiraButton::setMasks(QBitmap *bitmask, QBitmap *bitmaskDown){
@@ -1440,133 +1448,143 @@ void BaghiraClient::init()
       return;
    }
    noDeco_ = false;
-//     KConfig *config = new KConfig( "baghirarc" );
 #if KDE_IS_VERSION(3,3,91)
-    //first try if there's an X setting
-    unsigned char *data = 0;
-    Atom actual;
-    int format, result;
-    unsigned long n, left;
-    currentStyle = BaghiraFactory::defaultMode();
-    result = XGetWindowProperty(qt_xdisplay(), windowId(), baghira_deco_design, 0L, 1L, False, XA_CARDINAL, &actual, &format, &n, &left, &data);
-    if (result == Success && data != None) // found set design
-    {
-        memcpy (&currentStyle, data, sizeof (unsigned int));
-        currentStyle = currentStyle>3?3:currentStyle;
-    }
-    else // try if there's a definition file
-    {
-    XClassHint classHint;
-
-    if ( XGetClassHint( qt_xdisplay(), windowId(), &classHint ) )
-    {
-        FILE *file = NULL;
-        QString tmpString;
-        // overwrite file from bab starter? - don't worry, if there's been one and deleted by the style we've got the X setting (much better as it will take care of all subwindows)
-        tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + QString( classHint.res_class ).lower();
-        if( (file = fopen(tmpString.latin1(), "r")) != NULL )
-        {
+   //first try if there's an X setting
+   unsigned char *data = 0;
+   Atom actual;
+   int format, result;
+   unsigned long n, left;
+   currentStyle = BaghiraFactory::defaultMode();
+   result = XGetWindowProperty(qt_xdisplay(), windowId(), baghira_deco_design, 0L, 1L, False, XA_CARDINAL, &actual, &format, &n, &left, &data);
+   if (result == Success && data != None) // found set design
+   {
+      memcpy (&currentStyle, data, sizeof (unsigned int));
+      currentStyle = currentStyle>4?4:currentStyle;
+   }
+   else // try if there's a definition file
+   {
+      XClassHint classHint;
+      FILE *file = NULL;
+      if ( XGetClassHint( qt_xdisplay(), windowId(), &classHint ) )
+      {
+         QString tmpString;
+         // overwrite file from bab starter? - don't worry, if there's been one and deleted by the style we've got the X setting (much better as it will take care of all subwindows)
+         tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + QString( classHint.res_class ).lower();
+         if( (file = fopen(tmpString.latin1(), "r")) != NULL )
+         {
             fscanf(file,"%d\n%d\n", &format, &currentStyle);
             fclose(file);
             remove(tmpString.latin1()); // this is only temporary
-        }
-        else
-        {
+         }
+         else
+         {
             tmpString = QDir::homeDirPath() + "/.baghira/" + QString( classHint.res_class ).lower();
             if( (file = fopen(tmpString.latin1(), "r")) != NULL )
             {
                fscanf(file,"%d\n%d\n", &format, &currentStyle);
-                fclose(file);
+               fclose(file);
             }
-        }
-        XFree( classHint.res_name );
-        XFree( classHint.res_class );
-    }
-    }
-    if (currentStyle > 3) currentStyle = BaghiraFactory::defaultMode();
+         }
+         XFree( classHint.res_name );
+         XFree( classHint.res_class );
+      }
+      if (file == NULL)
+      {
+         QString tmpString = QDir::homeDirPath() + "/.baghira/.bab/.deco";
+         if( (file = fopen(tmpString.latin1(), "r")) != NULL )
+         {
+            fscanf(file,"%d\n%d\n", &format, &currentStyle);
+            fclose(file);
+         }
+      }
+   }
+   if (currentStyle > 4)
+      currentStyle = BaghiraFactory::defaultMode();
 #else
-    QSettings config;
-    config.beginGroup("/baghira/Style");
-    if (config.readBoolEntry( "Design_Default", 1 ) == 2)
-        {
-        currentStyle = 2;
-        config.endGroup();
-        }
-    else
-        {
-        config.endGroup();
-        config.beginGroup("/baghira/Deco");
-        int tmp = config.readNumEntry( "defaultMode", 1 );
-        currentStyle = (tmp > -1 && tmp < 4) ? tmp : 1;
-        config.endGroup();
-        }
+   QSettings config;
+   config.beginGroup("/baghira/Style");
+   if (config.readBoolEntry( "Design_Default", 1 ) == 2)
+   {
+      currentStyle = 2;
+      config.endGroup();
+   }
+   else
+   {
+      config.endGroup();
+      config.beginGroup("/baghira/Deco");
+      int tmp = config.readNumEntry( "defaultMode", 1 );
+      currentStyle = (tmp > -1 && tmp < 5) ? tmp : 1;
+      config.endGroup();
+   }
 #endif
-    createMainWidget( WResizeNoErase | WRepaintNoErase );
-    widget() ->installEventFilter( this );
-    widget() ->setBackgroundMode( NoBackground );
+   createMainWidget( WResizeNoErase | WRepaintNoErase );
+   widget() ->installEventFilter( this );
+   widget() ->setBackgroundMode( NoBackground );
 
-    if ( isTool() ) { // tool windows have tiny titlebars
-            titleheight_ = TITLESIZESMALL;
-    } else {
-            titleheight_ = TITLESIZE;
-    }
+   if ( isTool() ) // tool windows have tiny titlebars
+      titleheight_ = TITLESIZESMALL;
+   else
+      titleheight_ = TITLESIZE;
 
-    // setup layout
-    QVBoxLayout *mainlayout = new QVBoxLayout( widget() );
-    QHBoxLayout *titlelayout = new QHBoxLayout();
-    windowlayout = new QHBoxLayout();
+   // setup layout
+   QVBoxLayout *mainlayout = new QVBoxLayout( widget() );
+   QHBoxLayout *titlelayout = new QHBoxLayout();
+   windowlayout = new QHBoxLayout();
 
-    titlebar_ = new QSpacerItem( 1, titleheight_, QSizePolicy::Expanding,
-                                    QSizePolicy::Fixed );
-    mainlayout->setResizeMode( QLayout::FreeResize );
-    mainlayout->addLayout( titlelayout );
-    mainlayout->addLayout( windowlayout );
+   titlebar_ = new QSpacerItem( 1, titleheight_, QSizePolicy::Expanding, QSizePolicy::Fixed );
+   mainlayout->setResizeMode( QLayout::FreeResize );
+   mainlayout->addLayout( titlelayout );
+   mainlayout->addLayout( windowlayout );
 
-    windowlayout->addSpacing( BaghiraFactory::borderSize(currentStyle) );
-    if ( isPreview() ) {
-            windowlayout->addWidget(
-                new QLabel( i18n( "<b><center>Baghira preview</center></b>" ),
-                            widget() ) );
-    } else {
-            windowlayout->addItem( new QSpacerItem( 0, 18 ) );
-    }
-    windowlayout->addSpacing( BaghiraFactory::borderSize(currentStyle) );
+   windowlayout->addSpacing( BaghiraFactory::borderSize(currentStyle) );
+   if ( isPreview() )
+      windowlayout->addWidget( new QLabel( i18n( "<b><center>Baghira preview</center></b>" ), widget() ) );
+   else
+      windowlayout->addItem( new QSpacerItem( 0, 18 ) );
+   
+   windowlayout->addSpacing( BaghiraFactory::borderSize(currentStyle) );
 
-    leftClose = false;
-    rightClose = false;
-    performEasyClose = false;
-    
-    // setup titlebar
-    for ( int n = 0; n < ButtonTypeAmount; n++ )
-            button[ n ] = 0;
-    plusminus = 1;
-    addButtons( titlelayout, options() ->titleButtonsLeft() );
-    titlelayout->addItem( titlebar_ );
-    plusminus = -1;
-    isFaded = false;
-    addButtons( titlelayout, options() ->titleButtonsRight() );
+   leftClose = false;
+   rightClose = false;
+   performEasyClose = false;
+   
+   // setup titlebar
+   for ( int n = 0; n < ButtonTypeAmount; n++ )
+      button[ n ] = 0;
+   plusminus = 1;
+   addButtons( titlelayout, options() ->titleButtonsLeft() );
+   titlelayout->addItem( titlebar_ );
+   plusminus = -1;
+   isFaded = false;
+   addButtons( titlelayout, options() ->titleButtonsRight() );
 #if KDE_IS_VERSION(3,3,91)
-    grip = 0;
+   grip = 0;
 #endif
 
-    if (BaghiraFactory::effect(currentStyle, true) >= Baghira::Brushed || BaghiraFactory::effect(currentStyle, false) >= Baghira::Brushed) HandlePix = QPixmap(BaghiraFactory::pix(currentStyle, TitleBar, isActive(), false ));
-    else if ( BaghiraFactory::bgStipple() ) {
-        HandlePix = QPixmap( 32, 32);
-        QPainter painter;
-        QColor c = widget()->colorGroup().background();
-        HandlePix.fill(c);
-        painter.begin( &HandlePix );
-        painter.setPen( c.dark( 100 + (BaghiraFactory::contrast()/2) ) );
-        for ( int i = 1; i < 32; i += 4 ) {
-            painter.drawLine( 0, i, 31, i );
-            painter.drawLine( 0, i+2, 31, i+2 );
-        }
-        painter.setPen( c.dark( 100 + BaghiraFactory::contrast() ) );
-        for ( int i = 2; i < 31; i += 4 ) {
-            painter.drawLine( 0, i, 31, i );
-        }
-        painter.end();
-    }
+   if (BaghiraFactory::effect(currentStyle, true) >= Baghira::Brushed || BaghiraFactory::effect(currentStyle, false) >= Baghira::Brushed)
+      HandlePix = QPixmap(BaghiraFactory::pix(currentStyle, TitleBar, isActive(), false ));
+   else if ( BaghiraFactory::bgStipple() )
+   {
+      HandlePix = QPixmap( 32, 32);
+      QPainter painter;
+      QColor c = widget()->colorGroup().background();
+      HandlePix.fill(c);
+      painter.begin( &HandlePix );
+      painter.setPen( c.dark( 100 + (BaghiraFactory::contrast()/2) ) );
+      
+      for ( int i = 1; i < 32; i += 4 )
+      {
+         painter.drawLine( 0, i, 31, i );
+         painter.drawLine( 0, i+2, 31, i+2 );
+      }
+      
+      painter.setPen( c.dark( 100 + BaghiraFactory::contrast() ) );
+      
+      for ( int i = 2; i < 31; i += 4 )
+         painter.drawLine( 0, i, 31, i );
+      
+      painter.end();
+   }
 }
 
 QString BaghiraClient::caption() const
@@ -1742,29 +1760,18 @@ void BaghiraClient::addButtons( QBoxLayout *layout, const QString& s )
 				break;
 				
 			case 'F': // Above button
-				if ((!button[AboveButton])) {
-				button[AboveButton] = new BaghiraButton(this, "above", i18n("Keep Above Others"), isTool(), AboveButton);
-                                button[AboveButton]->setDown( keepAbove() );
-				connect(button[AboveButton], SIGNAL(clicked()), this, SLOT(aboveButtonPressed()));
-				layout->addWidget(button[AboveButton]);
-                                buttonAdded = true;
-				excursion = excursion + plusminus * BUTTONSIZE;
-                                if (BaghiraFactory::effect(currentStyle, true) == Baghira::Brushed) button[ AboveButton ]->setMasks(m, mD);
-				}
-				break;
-		
 			case 'B': // Below button
-				if ((!button[BehindButton])) {
-				button[BehindButton] = new BaghiraButton(this, "below", i18n("Keep Below Others"), isTool(), BehindButton);
-                                button[BehindButton]->setDown( keepBelow() );
-				connect(button[BehindButton], SIGNAL(clicked()), this, SLOT(belowButtonPressed()));
-				layout->addWidget(button[BehindButton]);
-                                buttonAdded = true;
-				excursion = excursion + plusminus * BUTTONSIZE;
-                                if (BaghiraFactory::effect(currentStyle, true) == Baghira::Brushed) button[ BehindButton ]->setMasks(m, mD);
+				if ((!button[AboveBelowButton]))
+				{
+               button[AboveBelowButton] = new BaghiraButton(this, "above", i18n("Keep Above/Below Others"), isTool(), AboveBelowButton);
+   				button[AboveBelowButton]->setDown( keepAbove() || keepBelow() );
+               connect(button[AboveBelowButton], SIGNAL(clicked()), this, SLOT(aboveBelowButtonPressed()));
+               layout->addWidget(button[AboveBelowButton]);
+               buttonAdded = true;
+               excursion = excursion + plusminus * BUTTONSIZE;
+               if (BaghiraFactory::effect(currentStyle, true) == Baghira::Brushed) button[ AboveBelowButton ]->setMasks(m, mD);
 				}
 				break;
-		
 			case 'L': // Shade button
 				if ((!button[ShadeButton] && isShadeable())) {
 				button[ShadeButton] = new BaghiraButton(this, "shade", isSetShade() ? tip = i18n("Unshade") : tip = i18n("Shade"), isTool(), ShadeButton);
@@ -1817,7 +1824,7 @@ bool BaghiraClient::eventFilter( QObject *obj, QEvent *e )
 		}
 	case QEvent::MouseButtonPress: {
             if (titlebar_->geometry().contains( static_cast<QMouseEvent *>(e)->pos() ) && static_cast<QMouseEvent *>(e)->state() == Qt::ControlButton){
-                currentStyle < 3 ? currentStyle++ : currentStyle = 0;
+                currentStyle < 4 ? currentStyle++ : currentStyle = 0;
 #if KDE_IS_VERSION(3,3,91)
                 unsigned long wmDesign = currentStyle;
                 XChangeProperty(qt_xdisplay(), windowId(), baghira_deco_design, XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &wmDesign, 1L);
@@ -2580,14 +2587,31 @@ void BaghiraClient::menuButtonPressed() {
 //////////////////////////////////////////////////////////////////////////////
 // new stuff
 
-void BaghiraClient::aboveButtonPressed(){
-    button[ AboveButton ] ->setDown(!keepAbove());
-    setKeepAbove(!keepAbove() );
-}
-void BaghiraClient::belowButtonPressed(){
-    button[ BehindButton ] ->setDown(!keepBelow());
-    setKeepBelow(!keepBelow() );
+void BaghiraClient::aboveBelowButtonPressed()
+{
+   if (keepAbove())
+   {
+      button[ AboveBelowButton ] ->setDown(true);
+      setKeepAbove(false );
+      setKeepBelow(true );
+      button[ AboveBelowButton ] ->repaint( false );
+   }
+   else if (keepBelow())
+   {
+      button[ AboveBelowButton ] ->setDown(false);
+      setKeepBelow(false );
+      setKeepAbove(false );
+      button[ AboveBelowButton ] ->repaint( false );
+   }
+   else
+   {
+      button[ AboveBelowButton ] ->setDown(true);
+      setKeepBelow(false );
+      setKeepAbove(true );
+      button[ AboveBelowButton ] ->repaint( false );
+   }
 }
+
 void BaghiraClient::shadeButtonPressed(){
     button[ ShadeButton ]->setDown(!isShade());
     setShade( !isShade() );
