@@ -65,9 +65,8 @@ enum ButtonType{
 	MaxButton,
 	CloseButton,
 	StickyButton,
-	AboveButton,
-	BehindButton,
 	ShadeButton,
+   AboveBelowButton,
 	MenuButton,
 	HelpButton,
 	ButtonTypeAmount,
@@ -145,7 +144,7 @@ protected:
     void setPixmap(int i, QImage &image);
 private:
     BaghiraClient *client_;
-    QPixmap pixmap[4];
+    QPixmap pixmap[5];
     void setState(int i);
 };
 
@@ -159,12 +158,12 @@ public:
     virtual KDecoration *createDecoration(KDecorationBridge *b);
     virtual bool reset(unsigned long changed);
     virtual QValueList<BorderSize> borderSizes() const;
-    static QPixmap &BaghiraFactory::ButtonPixmap(Baghira::WindowState wState, Baghira::ButtonType type, Baghira::ButtonState state, int current, bool small);
-    QImage* BaghiraFactory::DecoImage(QPixmap *pix, int x, int y, int width, int height);
+    static QPixmap &ButtonPixmap(Baghira::WindowState wState, Baghira::ButtonType type, Baghira::ButtonState state, int current, bool small);
+    QImage* DecoImage(QPixmap *pix, int x, int y, int width, int height);
 
     static QBitmap helpMask, jaguarDownMask, jaguarMenuDownMask,
             jaguarMenuMask, jaguarMask, milkMenuDownMask,
-            milkMenuMask, milkMask, pantherMenuMask, pantherMask, milkDownMask;
+            milkMenuMask, milkMask, pantherMenuMask, pantherMask, milkDownMask, arrowUp, arrowDown;
 
     static bool initialized();
     static bool noModalDeco();
@@ -214,27 +213,27 @@ private:
     static bool bgStipple_;
     static bool comicFrame_;
     static bool resizeGrip_;
-    static bool shape_ul[4], shape_ur[4], shape_ll[4], shape_lr[4];
+    static bool shape_ul[5], shape_ur[5], shape_ll[5], shape_lr[5];
     static bool allowEasyClosing_;
     static bool addAutoSpacing_;
     static bool maxResizable_;
-    static bool drawIcon_[4];
-    static ButtonStyle buttonStyle_[4];
-    static TitlebarType effect_[4][2];
+    static bool drawIcon_[5];
+    static ButtonStyle buttonStyle_[5];
+    static TitlebarType effect_[5][2];
     static Qt::AlignmentFlags titlealign_;
-    static QColor colors_[4][ColorTypeCount][2];
-    static KPixmap pix_[4][PixmapTypeCount][2][2];
-    static QPixmap ButtonPixmap_[4][WindowStateAmount][ButtonTypeAmount][ButtonStateAmount][2];
+    static QColor colors_[5][ColorTypeCount][2];
+    static KPixmap pix_[5][PixmapTypeCount][2][2];
+    static QPixmap ButtonPixmap_[5][WindowStateAmount][ButtonTypeAmount][ButtonStateAmount][2];
     static QColor ButtonColor_[ButtonTypeAmount+1];
     static QColor brushedMetalColor;
-    static QPixmap nostalgia_[4][3][2];
+    static QPixmap nostalgia_[5][3][2];
     
     static int contrast_;
-   static int bordersize_[4];
+   static int bordersize_[5];
     static uint defaultMode_;
     static int minimumTitleHeight_;
-    static int _3DImpact_[4];
-    static int LineImpact_[4];
+    static int _3DImpact_[5];
+    static int LineImpact_[5];
     
     static bool tintBrush_;
     static bool showTitle_;
@@ -357,7 +356,7 @@ private:
    BaghiraClient *client_;
    ButtonType type_;
    QBitmap *deco_;
-   QPixmap *pixmap[2][4];
+   QPixmap *pixmap[2][5];
    KPixmap icon_;
    bool small_;
    int lastmouse_;
@@ -420,8 +419,7 @@ private slots:
     void doShape();
     void maxButtonPressed();
     void menuButtonPressed();
-    void aboveButtonPressed();
-    void belowButtonPressed();
+    void aboveBelowButtonPressed();
     void shadeButtonPressed();
 
 private:
