@@ -126,6 +126,22 @@ BaghiraConfig::BaghiraConfig(KConfig*, QWidget* parent)
    connect(dialog_->drawIcon_T, SIGNAL(toggled(bool)), SIGNAL(changed()));    
    connect(dialog_->_3DImpact_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
    connect(dialog_->borderSize_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   
+   connect(dialog_->activeColor1_S, SIGNAL(clicked()), SIGNAL(changed()));
+   connect(dialog_->activeColor2_S, SIGNAL(clicked()), SIGNAL(changed()));
+   connect(dialog_->inactiveColor1_S, SIGNAL(clicked()), SIGNAL(changed()));
+   connect(dialog_->inactiveColor2_S, SIGNAL(clicked()), SIGNAL(changed()));
+   connect(dialog_->buttonStyle_S, SIGNAL(activated(int)), SIGNAL(changed()));
+   connect(dialog_->shapeUL_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeUR_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeLL_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeLR_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->drawIcon_S, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->titleeffect_S, SIGNAL(activated(int)),  SIGNAL(changed()));
+   connect(dialog_->i_titleeffect_S, SIGNAL(activated(int)), SIGNAL(changed()));
+   connect(dialog_->_3DImpact_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->LineImpact_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->borderSize_S, SIGNAL(valueChanged(int)), SIGNAL(changed()));
 //     config_->endGroup();
 
 }
@@ -226,6 +242,22 @@ void BaghiraConfig::load(KConfig*)
    dialog_->_3DImpact_T->setValue(config_->readNumEntry("3DImpact_4",20));
    dialog_->borderSize_T->setValue(config_->readNumEntry("BorderSize_4",0));
    
+   dialog_->activeColor1_S->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_5",QColor(250,250,250).rgb())));
+   dialog_->inactiveColor1_S->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_5",QColor(230,230,230).rgb())));
+   dialog_->activeColor2_S->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_5",QColor(230,230,230).rgb())));
+   dialog_->inactiveColor2_S->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_5",QColor(250,250,250).rgb())));
+   dialog_->buttonStyle_S->setCurrentItem(config_->readNumEntry("ButtonStyle_5",0));
+   dialog_->titleeffect_S->setCurrentItem(config_->readNumEntry("TitleEffect_5", 0));
+   dialog_->i_titleeffect_S->setCurrentItem(config_->readNumEntry("inactiveTitleEffect_5", 0));
+   dialog_->shapeUL_S->setChecked(config_->readBoolEntry("ShapeUL_5",true));
+   dialog_->shapeUR_S->setChecked(config_->readBoolEntry("ShapeUR_5",true));
+   dialog_->shapeLL_S->setChecked(config_->readBoolEntry("ShapeLL_5",false));
+   dialog_->shapeLR_S->setChecked(config_->readBoolEntry("ShapeLR_5",false));
+   dialog_->drawIcon_S->setChecked(config_->readBoolEntry("drawIcon_5",true));
+   dialog_->_3DImpact_S->setValue(config_->readNumEntry("3DImpact_5",20));
+   dialog_->LineImpact_S->setValue(config_->readNumEntry("LineImpact_5",30));
+   dialog_->borderSize_S->setValue(config_->readNumEntry("BorderSize_5",0));
+   
     buttonDialog_->inactiveColor->setColor(QColor((unsigned int)config_->readNumEntry("InactiveButtonColor", QColor(255,255,255).rgb())));
     buttonDialog_->closeColor->setColor(QColor((unsigned int)config_->readNumEntry("CloseButtonColor", QColor(200,85,70).rgb())));
     buttonDialog_->minColor->setColor(QColor((unsigned int)config_->readNumEntry("MinButtonColor", QColor(230,155,40).rgb())));
@@ -323,6 +355,22 @@ void BaghiraConfig::save(KConfig*)
    config_->writeEntry("drawIcon_4", dialog_->drawIcon_T->isChecked());
    config_->writeEntry("3DImpact_4", dialog_->_3DImpact_T->value());
    config_->writeEntry("BorderSize_4", dialog_->borderSize_T->value());
+   
+   config_->writeEntry("activeColor1_5", (int)dialog_->activeColor1_S->color().rgb());
+   config_->writeEntry("activeColor2_5", (int)dialog_->activeColor2_S->color().rgb());
+   config_->writeEntry("inactiveColor1_5", (int)dialog_->inactiveColor1_S->color().rgb());
+   config_->writeEntry("inactiveColor2_5", (int)dialog_->inactiveColor2_S->color().rgb());
+   config_->writeEntry("ButtonStyle_5", dialog_->buttonStyle_S->currentItem());
+   config_->writeEntry("TitleEffect_5", dialog_->titleeffect_S->currentItem());
+   config_->writeEntry("inactiveTitleEffect_5", dialog_->i_titleeffect_S->currentItem());
+   config_->writeEntry("ShapeUL_5", dialog_->shapeUL_S->isChecked());
+   config_->writeEntry("ShapeUR_5", dialog_->shapeUR_S->isChecked());
+   config_->writeEntry("ShapeLL_5", dialog_->shapeLL_S->isChecked());
+   config_->writeEntry("ShapeLR_5", dialog_->shapeLR_S->isChecked());    
+   config_->writeEntry("drawIcon_5", dialog_->drawIcon_S->isChecked());
+   config_->writeEntry("3DImpact_5", dialog_->_3DImpact_S->value());
+   config_->writeEntry("LineImpact_5", dialog_->LineImpact_S->value());
+   config_->writeEntry("BorderSize_5", dialog_->borderSize_S->value());
     
     if (buttonDialog_->save){
     config_->writeEntry("InactiveButtonColor", (int)buttonDialog_->inactiveColor->Color().rgb());
@@ -421,6 +469,22 @@ void BaghiraConfig::defaults()
    dialog_->_3DImpact_T->setValue(20);
    dialog_->borderSize_T->setValue(0);
    
+   dialog_->activeColor1_S->setColor(QColor(250,250,250));
+   dialog_->inactiveColor1_S->setColor(QColor(230,230,230));
+   dialog_->activeColor2_S->setColor(QColor(230,230,230));
+   dialog_->inactiveColor2_S->setColor(QColor(250,250,250));
+   dialog_->buttonStyle_S->setCurrentItem(0);
+   dialog_->titleeffect_S->setCurrentItem(0);
+   dialog_->i_titleeffect_S->setCurrentItem(0);
+   dialog_->shapeUL_S->setChecked(true);
+   dialog_->shapeUR_S->setChecked(true);
+   dialog_->shapeLL_S->setChecked(false);
+   dialog_->shapeLR_S->setChecked(false);
+   dialog_->drawIcon_S->setChecked(true);
+   dialog_->_3DImpact_S->setValue(20);
+   dialog_->LineImpact_S->setValue(30);
+   dialog_->borderSize_S->setValue(0);
+   
 //   buttonDialog_->defaults();
 
     
