@@ -4,8 +4,6 @@
 //#include <qvariant.h>
 #include <qgroupbox.h>
 
-class QGridLayout;
-class QHBoxLayout;
 class QSlider;
 class QSpinBox;
 class QColor;
@@ -35,10 +33,6 @@ protected:
     QSpinBox *redValue;
     QSpinBox *greenValue;
     QSpinBox *blueValue;
-    QHBoxLayout *redLayout;
-    QHBoxLayout *greenLayout;
-    QHBoxLayout *blueLayout;
-    QGridLayout *gridLayout;
     QColor color_;
 //    QGroupBox *box;
 
