@@ -24,8 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #define _MENUAPPLET_CPP_
 
-#include "menuapplet.h"
-
+#include <qdir.h>
 #include <qdesktopwidget.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -45,6 +44,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <X11/Xlib.h>
 
+#include "menuapplet.h"
+
 /*
 
  KMenuBar from KDE3.1 and older won't work very well with this applet.
@@ -86,44 +87,37 @@ const long SUPPORTED_WINDOW_TYPES = NET::NormalMask | NET::DesktopMask | NET::Do
 
 Applet::Applet( const QString& configFile_P, QWidget* parent_P ) : KPanelApplet( configFile_P, Normal, 0, parent_P, "menuapplet" ), DCOPObject( "menuapplet" ), module( NULL ), active_menu( NULL ), selection( NULL ), selection_watcher( NULL ), desktop_menu( false ), topEdgeOffset( 0 )
 {
-   _maxWidth = parent_P ? parent_P->width() : QDesktopWidget().availableGeometry().width();
-   KConfig config("kicker_menubarpanelrc");
-   QStringList lst = config.groupList();
-   for ( QStringList::Iterator it = lst.begin(); it != lst.end(); ++it )
-   {
-      config.setGroup(*it);
-      if (config.readEntry("DesktopFile") == "menuapplet.desktop")
-      {
-         _maxWidth = config.readNumEntry("WidthForHeightHint", _maxWidth);
-         break;
-      }
-   }
+   KConfig config(QDir::homeDirPath() + "/.qt/baghirarc");
+   config.setGroup("Menubar");
+   _maxWidth = config.readNumEntry("Width", QDesktopWidget().availableGeometry().width());
    _menuMover = new QLabel("<<|>>", this );
    _menuMover->adjustSize();
    _menuMover->setFixedSize(_menuMover->size());
+   _menuMover->move(_maxWidth - _menuMover->width(),0);
    _menuMover->hide();
    _menuMover->installEventFilter(this);
-   // for windowindicator
-//    windowTitleDict = QIntDict<QString>(97); //allowing 97 entries - should be enough, if not - who cares: just a label and hashtables are slightly faster than lists...
-   windowIndicator = new KMenuBar(this);
-   windowIndicator->setTopLevelMenu(false);
+   windowIndicator = new QMenuBar(this);
    windowIndicator->installEventFilter(this);
    windowIndicator->setBackgroundOrigin(QWidget::WidgetOrigin);
-   QFont tmpFont = KGlobalSettings::menuFont();
-   tmpFont.setBold(true);
-   windowIndicator->setFont(tmpFont);
-//    (const_cast<QFont*>(&windowIndicator->font()))->setBold(true);
+   windowIndicator->setLineWidth(0);
    windowList = new KWindowListMenu(windowIndicator);
    connect(windowList, SIGNAL(aboutToShow()), this, SLOT(initPopup()));
    windowIndicator->insertItem( "KDE", windowList, 0);
+   QFont tmpFont = KGlobalSettings::menuFont();
+   windowIndicator->setFont(tmpFont);
+//    windowIndicator->adjustSize();
+//    int tmpHeight = windowIndicator->height();
+   tmpFont.setBold(true);
+   windowIndicator->setFont(tmpFont);
+   windowIndicator->adjustSize();
+//    windowIndicator->setMargin((tmpHeight-windowIndicator->height()));
    windowIndicator->move(0,0);
    windowIndicator->show();
-   windowIndicator->adjustSize();
-   windowIndicator->setMinimumWidth ( windowIndicator->width() + 1 );
-   windowIndicator->setFixedSize(windowIndicator->size());
+   windowIndicator->setFixedWidth(windowIndicator->width() + 1);
    //==============
    // toolbarAppearanceChanged(int) is sent when changing macstyle
    connect( kapp, SIGNAL( toolbarAppearanceChanged( int )), this, SLOT( readSettings()));
+   connect( kapp, SIGNAL( kdisplayFontChanged()), this, SLOT( fontChanged()));
    claimSelection();
    readSettings();
    updateTopEdgeOffset();
@@ -138,6 +132,20 @@ Applet::~Applet()
    KGlobal::locale()->removeCatalogue("kmenuapplet");
 }
 
+void Applet::fontChanged()
+{
+   if (!windowIndicator)
+      return;
+   QFont tmpFont = KGlobalSettings::menuFont();
+//    windowIndicator->setFont(tmpFont);
+//    windowIndicator->adjustSize();
+//    int tmpHeight = windowIndicator->height();
+   tmpFont.setBold(true);
+   windowIndicator->setFont(tmpFont);
+   windowIndicator->adjustSize();
+//    windowIndicator->setMargin((tmpHeight-windowIndicator->height())/2);
+}
+
 void Applet::showWindowList()
 {
 	/*
@@ -231,13 +239,6 @@ bool Applet::eventFilter(QObject *o, QEvent *ev)
         return FALSE;
     }
 
-void Applet::windowRemoved(WId w_P)
-// another helping slot
-{
-//    windowTitleDict.setAutoDelete(TRUE);
-//    windowTitleDict.remove(w_P);
-}
-
 void Applet::windowAdded( WId w_P )
 {
    NETWinInfo info( qt_xdisplay(), w_P, qt_xrootwin(), NET::WMWindowType );
@@ -257,17 +258,8 @@ void Applet::windowAdded( WId w_P )
     else
     {
        KWin::WindowInfo info2 = KWin::windowInfo( transient_for, NET::WMWindowType | NET::WMName );
-        embed = new MenuEmbed( transient_for, info2.windowType( SUPPORTED_WINDOW_TYPES ) == NET::Desktop, this );
-//     }
+      embed = new MenuEmbed( transient_for, info2.windowType( SUPPORTED_WINDOW_TYPES ) == NET::Desktop, this );
       // ========= NAMING ===================
-//    if (!windowTitleDict[w_P] && w_P != qt_xrootwin())
-//    {
-      // causes crashes...
-//         if (windowTitleDict[transient_for])
-//             windowTitleDict.insert(w_P, windowTitleDict[transient_for]);
-//         else
-//       {
-//          KWin::WindowInfo tmpInfo = KWin::windowInfo( w_P, NET::WMName );
          QString title(info2.name());
          XClassHint classHint;
          if (XGetClassHint( qt_xdisplay(), w_P, &classHint ) )
@@ -310,9 +302,7 @@ void Applet::windowAdded( WId w_P )
             }
          }
        embed->title = title;
-//          windowTitleDict.insert(w_P, title); // add title
       }
-//    }
     // ========= NAMING DONE ==============
 #if 0
     embed->installEventFilter(this);
@@ -350,15 +340,15 @@ void Applet::activeWindowChanged( WId w_P )
          if( window == (*it)->mainWindow())
          {
             windowIndicator->changeItem(0, (*it)->title);
-            windowIndicator->setMinimumSize(0, windowIndicator->height());
-            windowIndicator->setMaximumSize(20000, windowIndicator->height());
+            windowIndicator->setMinimumWidth(0);//, windowIndicator->height());
+            windowIndicator->setMaximumWidth(20000);//, windowIndicator->height());
             windowIndicator->adjustSize();
-            windowIndicator->setMinimumWidth ( windowIndicator->width() + 1 );
-            windowIndicator->setFixedSize(windowIndicator->size());
+//             windowIndicator->resize(windowIndicator->width() + 1, height());
+            windowIndicator->setFixedWidth(windowIndicator->width() + 1);//, oldheight + topEdgeOffset);
             activateMenu( *it );
             if (active_menu->width() + windowIndicator->width() > _maxWidth)
             {
-               _menuMover->move(width() - _menuMover->width(),0);
+//                _menuMover->move(width() - _menuMover->width(),0);
                _menuMover->raise();
                _menuMover->show();
             }
@@ -389,15 +379,15 @@ void Applet::activeWindowChanged( WId w_P )
          if( (*it)->isDesktopMenu())
          {
             windowIndicator->changeItem(0, "KDE");
-            windowIndicator->setMinimumSize(0, windowIndicator->height());
-            windowIndicator->setMaximumSize(20000, windowIndicator->height());
+            windowIndicator->setMinimumWidth(0);//, windowIndicator->height());
+            windowIndicator->setMaximumWidth(20000);//, windowIndicator->height());
             windowIndicator->adjustSize();
-            windowIndicator->setMinimumWidth ( windowIndicator->width() + 1 );
-            windowIndicator->setFixedSize(windowIndicator->size());
+//             windowIndicator->resize(windowIndicator->width() + 1, height());
+            windowIndicator->setFixedWidth(windowIndicator->width() + 1);//, oldheight + topEdgeOffset);
             activateMenu( *it );
             if (active_menu->width() + windowIndicator->width() > _maxWidth)
             {
-               _menuMover->move(width() - _menuMover->width(),0);
+//                _menuMover->move(width() - _menuMover->width(),0);
                _menuMover->raise();
                _menuMover->show();
             }
@@ -408,11 +398,11 @@ void Applet::activeWindowChanged( WId w_P )
       }
    }
    windowIndicator->changeItem(0, "KDE");
-   windowIndicator->setMinimumSize(0, windowIndicator->height());
-   windowIndicator->setMaximumSize(20000, windowIndicator->height());
+   windowIndicator->setMinimumWidth(0);//, windowIndicator->height());
+   windowIndicator->setMaximumWidth(20000);//, windowIndicator->height());
    windowIndicator->adjustSize();
-   windowIndicator->setMinimumWidth ( windowIndicator->width() + 1 );
-   windowIndicator->setFixedSize(windowIndicator->size());
+//    windowIndicator->resize(windowIndicator->width() + 1, height());
+   windowIndicator->setFixedWidth(windowIndicator->width() + 1);//, oldheight + topEdgeOffset);
    activateMenu( NULL );
 }
 
@@ -495,6 +485,11 @@ void Applet::updateTopEdgeOffset()
       topEdgeOffset = 0;
    if( active_menu != NULL )
       active_menu->move( active_menu->x(), -topEdgeOffset );
+//     if (windowIndicator)
+//     {
+//        windowIndicator->resize(windowIndicator->width(), height() + topEdgeOffset );
+//        windowIndicator->move(windowIndicator->x(), -topEdgeOffset );
+//     }
 }
 
 void Applet::paletteChange(const QPalette & /* oldPalette */)
@@ -518,7 +513,6 @@ void Applet::claimSelection()
       connect( selection, SIGNAL( lostOwnership()), SLOT( lostSelection()));
       module = new KWinModule;
       connect( module, SIGNAL( windowAdded( WId )), this, SLOT( windowAdded( WId )));
-      connect( module, SIGNAL( windowRemoved( WId )), this, SLOT( windowRemoved( WId )));
       connect( module, SIGNAL( activeWindowChanged( WId )), this, SLOT( activeWindowChanged( WId )));
       QValueList< WId > windows = module->windows();
       for( QValueList< WId >::ConstIterator it = windows.begin(); it != windows.end(); ++it )
@@ -646,6 +640,7 @@ bool MenuEmbed::x11Event( XEvent* ev_P )
       {
          resize( ev.width > _maxWidth ? _maxWidth : ev.width, ev.height );
          static_cast< Applet* >( parent())->updateMenuGeometry( this );
+//          windowIndicator->resize(windowIndicator->width(), ev.height);
       }
       sendSyntheticConfigureNotifyEvent();
 //        int x, y;
