@@ -54,6 +54,7 @@ k_dcop:
    ASYNC configure();
    virtual void showWindowList();
 public:
+   friend class MenuEmbed;
    Applet( const QString& configFile, QWidget *parent );
    virtual ~Applet();
    virtual int widthForHeight( int height ) const;
@@ -64,6 +65,7 @@ protected:
    virtual void paletteChange(const QPalette& );
    virtual void positionChange( Position p );
    bool eventFilter(QObject *, QEvent *ev);
+   QMenuBar *windowIndicator;
 private slots:
    void moveMenu();
    void windowAdded( WId w );
@@ -73,7 +75,7 @@ private slots:
    void claimSelection();
    // to show current active window (not necessary equal to the menubar)
    void initPopup();
-   void windowRemoved(WId w);
+   void fontChanged();
 private:
    bool isDisabled() const; // does it own the manager selection?
    WId tryTransientFor( WId w );
@@ -88,9 +90,6 @@ private:
    bool desktop_menu;
    DCOPClient dcopclient;
    int topEdgeOffset;
-   // to show current active window (not necessary equal to the menubar)   
-   KMenuBar *windowIndicator;
-//    QIntDict<QString>windowTitleDict;
    KWindowListMenu* windowList;
    QHBoxLayout *layout;
    QLabel *_menuMover;
