@@ -39,6 +39,17 @@
 
 ResizingLinkBox::ResizingLinkBox( QWidget * parent, const char * name, WFlags f ) : KListBox( parent, name, f)
 {
+   KConfig config(QDir::homeDirPath() + "/.qt/baghirarc");
+   config.setGroup("Sidebar");
+   size_ = config.readNumEntry (QString(name) + "_IconSize", 48);
+   popupMenu = new KPopupMenu;
+   popupMenu->insertTitle (i18n("Icon Size"),122,122);
+   popupMenu->insertItem("16x16", this, SLOT(setIconSize(int)),0,16,123);
+   popupMenu->insertItem("22x22", this, SLOT(setIconSize(int)),0,22,124);
+   popupMenu->insertItem("32x32", this, SLOT(setIconSize(int)),0,32,125);
+   popupMenu->insertItem("48x48", this, SLOT(setIconSize(int)),0,48,126);
+   popupMenu->insertItem("64x64", this, SLOT(setIconSize(int)),0,64,127);
+   popupMenu->insertItem("128x128", this, SLOT(setIconSize(int)),0,128,128);
 }
 
 void ResizingLinkBox::insertItem( const QListBoxItem *lbi, int index )
@@ -55,15 +66,49 @@ void ResizingLinkBox::insertItem( const QListBoxItem *lbi, const QListBoxItem *a
       emit itemNumberChanged(TRUE);
 }
 
+
+void ResizingLinkBox::insertItem( const QString & icon, const QString & title, const QString & url )
+{
+   insertItem( new ListBoxLink(icon, size_, title, url ) );
+}
+
 void ResizingLinkBox::removeItem( int index )
 {
+   blockSignals ( true );
    KListBox::removeItem(index);
+   blockSignals ( false );
    emit itemNumberChanged(FALSE);
 }
 
+void ResizingLinkBox::setIconSize(int size)
+{
+   size_ = size;
+   KConfig *config = new KConfig(QDir::homeDirPath() + "/.qt/baghirarc");
+   config->setGroup("Sidebar");
+   config->writeEntry (QString(name()) + "_IconSize", size);
+   config->sync();
+   ListBoxLink *runner;
+   ListBoxDevice *current;
+   blockSignals ( true );
+   for (uint i = 0; i < count(); i++)
+   {
+      runner = (ListBoxLink*)item(i);
+      if (dynamic_cast<ListBoxDevice*>(runner))
+      {
+         current = (ListBoxDevice*)runner;
+         insertItem( new ListBoxDevice(current->icon(), size, current->text(), current->URL(), current->name(), current->mountPoint(), current->mounted(), current->ejectable(), current->removable(), current->id()), i );
+      }
+      else
+      {
+         insertItem( new ListBoxLink(runner->icon(), size, runner->text(), runner->URL()), i );
+      }
+      KListBox::removeItem(i+1);
+   }
+   blockSignals ( false );
+}
+
 void ResizingLinkBox::mousePressEvent ( QMouseEvent *mpe )
 {
-   if (mpe->button() == Qt::LeftButton) return;
    KListBox::mousePressEvent( mpe );
 }
 
@@ -72,7 +117,7 @@ void ResizingLinkBox::mouseReleaseEvent ( QMouseEvent *mpe )
    if (mpe->button() == Qt::LeftButton)
    {
       ListBoxLink *link = (ListBoxLink*)itemAt(mpe->pos());
-      if (isSelected(link)) emit highlighted(link);
+      if (isSelected(link)) emit clicked(link);
       KListBox::mousePressEvent( mpe );
       return;
    }
@@ -87,12 +132,16 @@ void ResizingLinkBox::contentsWheelEvent ( QWheelEvent * we )
       emit scrolled(0, -we->delta());
 }
 
-MediaListBox::MediaListBox( QWidget * parent, uint size, const char * name, WFlags f ) : ResizingLinkBox(parent, name, f), DCOPObject("BaghiraSidebarIface")
+MediaListBox::MediaListBox( QWidget * parent, const char * name, WFlags f ) : ResizingLinkBox(parent, name, f), DCOPObject("BaghiraSidebarIface")
 {
-   size_ = size;
+   KConfig config(QDir::homeDirPath() + "/.qt/baghirarc");
+   config.setGroup("Sidebar");
+   hiddenDevices = config.readListEntry("HiddenDevices");
    currentFloppy = 0L;
-   floppyPopup = new KPopupMenu(this);
-   floppyPopup->insertItem(i18n("Format disk..."), this, SLOT(kfloppy()));
+   devicePopup = new KPopupMenu(this);
+   devicePopup->setCheckable ( true );
+   popupMenu->insertItem(i18n("Device List"), devicePopup, 1, 0);
+   popupMenu->insertSeparator( 0 );
 
 #if KDE_IS_VERSION(3,4,90)
    insertItem(new ListBoxDevice("system", size_, i18n("My Computer"), "system:/", "", "", TRUE, FALSE, FALSE));
@@ -120,6 +169,7 @@ MediaListBox::MediaListBox( QWidget * parent, uint size, const char * name, WFla
       {
          QStringList result;
          reply >> result;
+         blockSignals ( true );
          for (uint i = 0; i < result.size()/MEDIALIST_PROPS; i++)
          {
             if (result[MEDIALIST_PROPS*i+MIME_TYPE] != "media/hdd_mounted" &&
@@ -129,14 +179,42 @@ MediaListBox::MediaListBox( QWidget * parent, uint size, const char * name, WFla
                   result[MEDIALIST_PROPS*i+MIME_TYPE] != "media/smb_mounted" &&
                   result[MEDIALIST_PROPS*i+MIME_TYPE] != "media/smb_unmounted")
             {
-               insertItem(createListBoxDevice(result, i));
+               ListBoxDevice *dev = createListBoxDevice(result, i);
+               if (hiddenDevices.contains(dev->name()))
+               {
+                  deviceList.append(dev);
+                  devicePopup->setItemChecked(dev->id(),false);
+               }
+               else
+               {
+                  insertItem(dev);
+                  devicePopup->setItemChecked(dev->id(),true);
+               }
             }
          }
+         blockSignals ( false );
       }
       else
          qWarning("fullList() returned an unexpected type of reply!");
    }
-   setCurrentItem( 0 );
+//    setCurrentItem( 0 );
+}
+
+MediaListBox::~MediaListBox()
+{
+   hiddenDevices.clear();
+   ListBoxDevice *runner;
+   for ( runner = deviceList.first(); runner; runner = deviceList.next() )
+      hiddenDevices.append(runner->name());
+   KConfig config(QDir::homeDirPath() + "/.qt/baghirarc");
+   config.setGroup("Sidebar");
+   config.writeEntry("HiddenDevices", hiddenDevices);
+}
+
+void MediaListBox::removeItem( int index )
+{
+   devicePopup->removeItem(((ListBoxDevice*)item( index ))->id());
+   ResizingLinkBox::removeItem(index);
 }
 
 void MediaListBox::kfloppy()
@@ -152,6 +230,37 @@ void MediaListBox::kfloppy()
    return;
 }
 
+void MediaListBox::toggleDevice(int id)
+{
+   ListBoxDevice *runner;
+   if (devicePopup->isItemChecked(id)) // remove the device!
+   {
+      devicePopup->setItemChecked(id, false);
+      for (uint i = 0; i < count(); i++)
+      {
+         runner = (ListBoxDevice*)item(i);
+         if (runner->id() == id)
+         {
+            deviceList.append(runner);
+            blockSignals ( true );
+            takeItem(runner);
+            blockSignals ( false );
+            break;
+         }
+      }
+   }
+   else  // add the device!
+   {
+      devicePopup->setItemChecked(id, true);
+      for ( runner = deviceList.first(); runner; runner = deviceList.next() )
+         if (runner->id() == id)
+         {
+            insertItem(deviceList.take());
+            break;
+         }
+   }
+}
+
 ListBoxDevice *MediaListBox::createListBoxDevice(QStringList & deviceProperties, uint n)
 {
    QString icon;
@@ -171,9 +280,9 @@ ListBoxDevice *MediaListBox::createListBoxDevice(QStringList & deviceProperties,
       label = i18n(label.section( " (", 0, 0 ).utf8());
    }
 #if KDE_IS_VERSION(3,4,90)
-   return new ListBoxDevice( icon, size_, label, "system:/media/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"));
+   return new ListBoxDevice( icon, size_, label, "system:/media/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"), devicePopup->insertItem(deviceProperties[MEDIALIST_PROPS*n+NAME], this, SLOT(toggleDevice(int))));
 #else
-   return new ListBoxDevice( icon, size_, label, "media:/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"));
+   return new ListBoxDevice( icon, size_, label, "media:/"+deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+NAME], deviceProperties[MEDIALIST_PROPS*n+DEVICE_NODE], deviceProperties[MEDIALIST_PROPS*n+MOUNTED] == "true", icon.contains("dvd") || icon.contains("cdrom") || icon.contains("cdwriter"),icon.contains("floppy"),devicePopup->insertItem(deviceProperties[MEDIALIST_PROPS*n+NAME], this, SLOT(toggleDevice(int))));
 #endif
 }
 
@@ -203,7 +312,17 @@ void MediaListBox::mediumAdded(const QString &name)
       {
          QStringList result;
          reply >> result;
-         insertItem(createListBoxDevice(result));
+         ListBoxDevice *dev = createListBoxDevice(result);
+         if (hiddenDevices.contains(dev->name()))
+         {
+            deviceList.append(dev);
+            devicePopup->setItemChecked(dev->id(),false);
+         }
+         else
+         {
+            insertItem(dev);
+            devicePopup->setItemChecked(dev->id(),true);
+         }
       }
       else
          qWarning("properties() returned an unexpected type of reply!");
@@ -254,43 +373,58 @@ void MediaListBox::mediumChanged(const QString &name)
          int i = index(name);
          if (i<0)
             return;
+         
+         ListBoxDevice *device = createListBoxDevice(result);
+         if (hiddenDevices.contains(device->name()))
+         {
+            deviceList.append(device);
+            devicePopup->setItemChecked(device->id(),false);
+            return;
+         }
+         devicePopup->setItemChecked(device->id(),true);
+         blockSignals(true);
          if (i == currentItem()) // changing current item - take some care of updating stuff
          {
-            ListBoxDevice *device = createListBoxDevice(result);
             if (((ListBoxDevice*)item(i))->mounted() && !device->mounted()) // unmounted the device - we certainly do not wanna select it anymore
             {
                setCurrentItem(0);
                removeItem(i);
                insertItem(device, i);
             }
-            else // we're selected and wanna keep selection, but prevent i+1 from becoming selected (as this could trigger annoying cd mounts etc.)
+            else // we're selected and wanna keep selection
             {
-            insertItem(device, i+1); // pre insert the device behind the current one - no selection update (iff i was selected)
-            removeItem(i); // post remove the old icon
-            setSelected( i, TRUE ); // i is now former i+1 - our now item
+               removeItem(i);
+               insertItem(device, i);
+               setSelected( i, true );
             }
          }
          else // ordinary change
          {
             removeItem(i);
-            insertItem(createListBoxDevice(result), i);
+            insertItem(device, i);
          }
+         blockSignals(false);
       }
       else
          qWarning("properties() returned an unexpected type of reply!");
    }
 }
 
+#define _FLOPPYID_ 0
+#define _FLOPPYINDEX_ 0
+
 void MediaListBox::mousePressEvent ( QMouseEvent *mpe )
 {
    if (mpe->button() == Qt::RightButton)
    {
+      popupMenu->removeItem(_FLOPPYID_);
       ListBoxDevice *device = (ListBoxDevice*)itemAt(mpe->pos());
-      if (device->name().contains("fd"))
+      if (device && device->name().contains("fd"))
       {
          currentFloppy = device;
-         floppyPopup->popup(mpe->globalPos());
+         popupMenu->insertItem(i18n("Format disk..."), this, SLOT(kfloppy()),0,_FLOPPYID_,_FLOPPYINDEX_);
       }
+      popupMenu->popup(mpe->globalPos());
       return;
    }
    if (mpe->button() == Qt::LeftButton && mpe->x() > width()-22)
@@ -301,7 +435,7 @@ void MediaListBox::mousePressEvent ( QMouseEvent *mpe )
       {
          KProcess proc;
          device->ejectable()?
-            proc << "kdeeject" << "-q" << device->mountPoint():
+            proc << "kdeeject" /*<< "-q"*/ << device->mountPoint():
             proc << "umount" << device->mountPoint(); // umount?
          proc.start(KProcess::DontCare);
          proc.detach();
@@ -321,13 +455,12 @@ void MediaListBox::resizeEvent ( QResizeEvent * re)
    ResizingLinkBox::resizeEvent(re);
 }
 
-DnDListBox::DnDListBox( QWidget * parent, uint size, const char * name, WFlags f ):
-ResizingLinkBox( parent, name, f), size_(size), _poof(0), _poofIndex(0), _poofAnimPix(0), _poofPix(0)
+DnDListBox::DnDListBox( QWidget * parent, const char * name, WFlags f ):
+ResizingLinkBox( parent, name, f), _poof(0), _poofIndex(0), _poofAnimPix(0), _poofPix(0)
 {
    setAcceptDrops(true);
    dialog = new LinkConfig();
    connect(dialog->buttonOk, SIGNAL(clicked()), this, SLOT(updateLink()));
-   connect (this, SIGNAL(rightButtonPressed( QListBoxItem *, const QPoint & )), this, SLOT(configureLink(QListBoxItem *)));
    setCursor(Qt::PointingHandCursor);
 }
 
@@ -378,15 +511,8 @@ void DnDListBox::runPoof()
 void DnDListBox::dragEnterEvent ( QDragEnterEvent *dee )
 {
 //    dragging_ = true;
-   if (QUriDrag::canDecode(dee) || BaghiraLinkDrag::canDecode(dee))
+   if (QUriDrag::canDecode(dee) || BaghiraLinkDrag::canDecode(dee) || QTextDrag::canDecode(dee))
       dee->accept(true);
-   else if (QTextDrag::canDecode(dee))
-   {
-      QString string;
-      QCString subtype;
-      KURL url(string);
-      dee->accept(url.isValid() || string.contains('@') ||  string.contains("'at'")/*mail*/);
-   }
 }
 
 void DnDListBox::dropEvent ( QDropEvent *de )
@@ -461,7 +587,15 @@ void DnDListBox::mousePressEvent ( QMouseEvent *mpe )
 {
    if (mpe->button() == Qt::RightButton)
    {
-      emit rightButtonPressed ( itemAt(mpe->pos()), mpe->globalPos() );
+      currentItem = 0;
+      popupMenu->removeItem(0);
+      ListBoxDevice *device = (ListBoxDevice*)itemAt(mpe->pos());
+      if (device)
+      {
+         currentItem = device;
+         popupMenu->insertItem("Edit link...", this, SLOT(configureLink()),0,0,0);
+      }
+      popupMenu->popup(mpe->globalPos());
       return;
    }
    if (mpe->button() == Qt::MidButton)
@@ -528,11 +662,10 @@ void DnDListBox::pasteURL(int mode, QListBoxItem *after)
    }
 }
 
-void DnDListBox::configureLink(QListBoxItem *item)
+void DnDListBox::configureLink()
 {
-   if (item == 0L)
+   if (currentItem == 0L)
       return;
-   currentItem = (ListBoxLink*)item;
    dialog->title->setText(currentItem->text());
    dialog->url->setURL(currentItem->URL());
    dialog->icon->setIcon(currentItem->icon());
