@@ -1079,6 +1079,7 @@ void Panel::setOrientation ( Orientation ori )
 AppList::AppList(int size, QWidget * parent) : QScrollView(parent), _size(size)
 {
    popupBlocked_ = false;
+   enableClipper( true );
    setFrameStyle(QFrame::LineEditPanel | QFrame::Sunken );
    configDialog_ = new ConfigDialog;
    helpDialog_ = new HelpDialog;
@@ -1165,7 +1166,7 @@ void AppList::addEntry()
       fullpath.remove(0,1);
    }
    fullpath = KService::newServicePath(true, fullpath + configDialog_->appName->text());
-//    qWarning(fullpath);
+//qWarning("%s",fullpath.ascii());
    writeEntry(fullpath);
    KService *s = new KService(fullpath);
    QStringList list(KServiceGroup::group(configDialog_->category->currentText())->caption());
@@ -1178,8 +1179,9 @@ void AppList::addEntry()
 void AppList::removeEntry()
 {
    popupBlocked_ = true;
-   if (KMessageBox::questionYesNo (this, i18n("<qt>Are you sure you want to remove<br> %1</qt>").arg(handledEntry->title()), i18n("Remove ALI entry")))
+   if (KMessageBox::questionYesNo (this, i18n("<qt>Are you sure you want to remove<br> %1</qt>").arg(handledEntry->title()), i18n("Remove ALI entry")) == KMessageBox::Yes)
    {
+   qWarning("gonna delete!");
       writeEntry(handledEntry->m_service->locateLocal(), true);
       handledEntry->hide();
       entryList.removeRef(handledEntry);
@@ -1710,9 +1712,11 @@ void AppList::reset()
 
 StartMenu::StartMenu( int size, QWidget * parent, WFlags f ) : QWidget(parent, "StartMenu", f), _size(size), inMove(false)
 {
-   m_panelPos = StartMenu::South;
+   m_panelPos = StartMenu::Nowhere;
    panelLayout = new QGridLayout ( this, 3, 3 );
    config = new KConfig("bStarter", true, false);
+   config->setGroup("Shell");
+   history = config->readListEntry("History");
    config->setGroup("Settings");
    if (useKTTS = config->readBoolEntry("useKTTS", false))
       m_spokenText = 0;
@@ -1801,6 +1805,7 @@ StartMenu::StartMenu( int size, QWidget * parent, WFlags f ) : QWidget(parent, "
    mainLayout->addSpacing ( 3 );
    mainLayout->addWidget ( statusBar );
    panelLayout->addWidget ( m_panel, 2, 1 );
+   m_panel->hide();
    
    if (config) { delete config; config = 0L; }
 //    KDrawer *drawer = new KDrawer(this, KDrawer::Bottom);
@@ -1809,6 +1814,11 @@ StartMenu::StartMenu( int size, QWidget * parent, WFlags f ) : QWidget(parent, "
 void StartMenu::save()
 {
    config = new KConfig("bStarter", false, false);
+   config->setGroup("Shell");
+   QStringList lst;
+   for ( QStringList::Iterator it = history.begin(); it != history.end(); ++it )
+      lst.prepend(*it);
+   config->writeEntry("History", lst);
    config->setGroup("Settings");
    config->writeEntry("firstUse", false);
    appList->save(config);
@@ -1976,7 +1986,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
    {
    case StartMenu::South:
       m_panel->show();
-      if (m_panelPos == StartMenu::West || m_panelPos == StartMenu::East )
+      if (m_panelPos == StartMenu::Nowhere || m_panelPos == StartMenu::West || m_panelPos == StartMenu::East )
       {
 //          m_panel->set2SizePolicies(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
          m_panel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -1988,7 +1998,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
       break;
    case StartMenu::West:
       m_panel->show();
-      if (m_panelPos == StartMenu::South || m_panelPos == StartMenu::North )
+      if (m_panelPos == StartMenu::Nowhere || m_panelPos == StartMenu::South || m_panelPos == StartMenu::North )
       {
 //          m_panel->set2SizePolicies(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
          m_panel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
@@ -2000,7 +2010,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
       break;
    case StartMenu::East:
       m_panel->show();
-      if (m_panelPos == StartMenu::South || m_panelPos == StartMenu::North )
+      if (m_panelPos == StartMenu::Nowhere || m_panelPos == StartMenu::South || m_panelPos == StartMenu::North )
       {
 //          m_panel->set2SizePolicies(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
          m_panel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
@@ -2012,7 +2022,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
       break;
    case StartMenu::North:
       m_panel->show();
-      if (m_panelPos == StartMenu::West || m_panelPos == StartMenu::East )
+      if (m_panelPos == StartMenu::Nowhere || m_panelPos == StartMenu::West || m_panelPos == StartMenu::East )
       {
 //          m_panel->set2SizePolicies(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
          m_panel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -2024,7 +2034,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
       break;
    default:
       m_panel->hide();
-      break;
+//       break;
    }
    m_panelPos = p;
 }
@@ -2032,6 +2042,7 @@ void StartMenu::setPanelPosition(PanelPosition p)
 void StartMenu::execute(const QString& command)
 // adapted from kicker run applet - far more convenient ;)
 {
+   history.remove(command);
    history.append(command); // all - the list is not stored and the user may want to easily correct mistypes of LOOOOOOOOOOOOOOOOOOOONG commands with a lot of "\ "... ;P
    QString exec;
    
