@@ -308,8 +308,14 @@ void starter::unblockPopupDelayed()
 void starter::unblockPopup()
 {
    popupBlocked = false;
+   if (mainView->hasMouse())
+      mainView->setPixmap(hoverPixmap);
+   else
+      mainView->setPixmap(startMenu->isShown() ? downPixmap : pixmap);
+   mainView->repaint();
 }
 
+#define _MAX_(a,b) (a > b ? a : b)
 void starter::popupMenu()
 {
    if (popupBlocked)
@@ -317,18 +323,23 @@ void starter::popupMenu()
    {
 //       if (!isDialog_)
 //          return;
-      
+      startMenu->setMinimumSize ( 0, 0 );
+      startMenu->setMaximumSize ( 32767, 32767 );
       setActiveWindow();
+      startMenu->setPanelPosition((StartMenu::PanelPosition)configDialog->popupPanelPos->currentItem());
       if (configDialog->customPopupSize->isChecked())
       {
-         startMenu->setFixedSize(configDialog->popupW->value(),configDialog->popupH->value());
+         startMenu->resize(configDialog->popupW->value(),configDialog->popupH->value());
+         startMenu->setFixedSize(startMenu->size());
+//          startMenu->setFixedSize(_MAX_(configDialog->popupW->value(), startMenu->minimumWidth()), _MAX_(configDialog->popupH->value(), startMenu->minimumHeight()));
       }
       else
       {
          QRect desktop = QDesktopWidget().availableGeometry( startMenu );
-         startMenu->setFixedSize(desktop.width()/5,2*desktop.height()/3); // 1/5 screen width, 2/3 screen height
+         startMenu->resize(desktop.width()/5, 2*desktop.height()/3);
+         startMenu->setFixedSize(startMenu->size());
+//          startMenu->setFixedSize(_MAX_(startMenu->minimumWidth(), desktop.width()/5) ,_MAX_(startMenu->minimumHeight(), 2*desktop.height()/3)); // 1/5 screen width, 2/3 screen height
       }
-      startMenu->setPanelPosition((StartMenu::PanelPosition)configDialog->popupPanelPos->currentItem());
       
       QPoint pt = mapToGlobal(pos());
       QRect desktop = QDesktopWidget().availableGeometry( startMenu );
@@ -369,15 +380,22 @@ void starter::popupMenu()
 
 void starter::showMenu()
 {
+   startMenu->setMinimumSize ( 0, 0 );
+   startMenu->setMaximumSize ( 32767, 32767 );
+   startMenu->setPanelPosition((StartMenu::PanelPosition)configDialog->dialogPanelPos->currentItem());
    if (configDialog->customDialogSize->isChecked())
    {
-      startMenu->setFixedSize(configDialog->dialogW->value(),configDialog->dialogH->value());
+      startMenu->resize(configDialog->dialogW->value(), configDialog->dialogH->value());
+      startMenu->setFixedSize(startMenu->size());
+//       startMenu->setFixedSize(_MAX_(configDialog->dialogW->value(), startMenu->minimumWidth()), _MAX_(startMenu->minimumHeight(), configDialog->dialogH->value()));
    }
    else
    {
       QRect desktop = QDesktopWidget().availableGeometry( startMenu );
 //    setActiveWindow();
-      startMenu->setFixedSize(desktop.width()/2,desktop.width()*9/32); // 16:9 window, width == 1/2 screen
+      startMenu->resize(desktop.width()/2, desktop.width()*9/32);
+      startMenu->setFixedSize(startMenu->size());
+//       startMenu->setFixedSize(_MAX_(startMenu->minimumWidth(), desktop.width()/2) , _MAX_(startMenu->minimumHeight(), desktop.width()*9/32)); // 16:9 window, width == 1/2 screen
    }
    QPoint pt;
    if (configDialog->customDialogPos->isChecked())
@@ -400,7 +418,6 @@ void starter::showMenu()
       QRect desktop = QDesktopWidget().availableGeometry( startMenu );
       pt = QPoint((desktop.right() - startMenu->width())/2, (desktop.bottom() - startMenu->height())/2);
    }
-   startMenu->setPanelPosition((StartMenu::PanelPosition)configDialog->dialogPanelPos->currentItem());
    if (configDialog->showDialogTitlebar->isChecked())
       startMenu->reparent(this, Qt::WType_TopLevel, pt, true);
    else
@@ -409,54 +426,49 @@ void starter::showMenu()
 
 bool starter::eventFilter( QObject*, QEvent *e )
 {
-    switch (e->type())
-    {
-        case QEvent::Enter:
-        {
+   switch (e->type())
+   {
+      case QEvent::Enter:
+      {
+         mainView->setPixmap(hoverPixmap);
+         mainView->repaint();
+         return TRUE;
+      }
+      case QEvent::Leave:
+      {
+         mainView->setPixmap(startMenu->isShown() ? downPixmap : pixmap);
+         mainView->repaint();
+         return TRUE;
+      }
+      case QEvent::MouseButtonPress:
+      {
+         if (((QMouseEvent*)e)->button() == Qt::RightButton)
+         {
+            configPopup->popup(((QMouseEvent*)e)->globalPos());
+            return TRUE;
+         }
+         if (((QMouseEvent*)e)->button() == Qt::LeftButton)
+         {
+            mainView->setPixmap(downPixmap);
+            mainView->repaint();
+            popupMenu();
+         }
+         return TRUE;
+      }
+      case QEvent::MouseButtonRelease:
+      {
+         if (((QMouseEvent*)e)->button() != Qt::LeftButton)
+               return FALSE;
+         if (mainView->hasMouse())
             mainView->setPixmap(hoverPixmap);
-            mainView->repaint();
-            return TRUE;
-        }
-        case QEvent::Leave:
-        {
-            mainView->setPixmap(pixmap);
-            mainView->repaint();
-            return TRUE;
-        }
-        case QEvent::MouseButtonPress:
-        {
-           if (((QMouseEvent*)e)->button() == Qt::RightButton)
-           {
-              configPopup->popup(((QMouseEvent*)e)->globalPos());
-              return TRUE;
-           }
-            if (((QMouseEvent*)e)->button() == Qt::LeftButton)
-            {
-               mainView->setPixmap(downPixmap);
-               mainView->repaint();
-               popupMenu();
-            }
-            return TRUE;
-        }
-        case QEvent::MouseButtonRelease:
-        {
-           if (((QMouseEvent*)e)->button() != Qt::LeftButton)
-                return FALSE;
-            if (mainView->hasMouse())
-                {
-                mainView->setPixmap(hoverPixmap);
-                mainView->repaint();
-                }
-            else
-                {
-                    mainView->setPixmap(pixmap);
-                mainView->repaint();
-                }
-            return TRUE;
-        }
-        default:
-            return FALSE;
-    }
+         else
+            mainView->setPixmap(startMenu->isShown() ? downPixmap : pixmap);
+         mainView->repaint();
+         return TRUE;
+      }
+      default:
+         return FALSE;
+   }
 }
 
 extern "C"
