@@ -11,7 +11,7 @@
 #include <qwidget.h>
 #include <kstyle.h>
 
-#define BITMAP_ITEMS 89 // Don't worry, they're demand loaded ;-)
+// #define BITMAP_ITEMS 75 // Don't worry, they're demand loaded ;-)
 #define LIQUID_MENU_CHANGE 667
 #define MOSFET_BUTTON_CHANGE 661
 
@@ -32,20 +32,16 @@ class LiquidStyle;
 enum BitmapData{RadioOn = 0, RadioOff, RadioOnHover, RadioOffHover, RadioOnPressed, RadioOffPressed,
 		VSBSliderTop, VSBSliderMid, VSBSliderBtm,
 		VSBSliderTopActive, VSBSliderMidActive, VSBSliderBtmActive,
-		VSBSliderTopHover, VSBSliderMidHover, VSBSliderBtmHover,
 		VSBSliderTopPressed, VSBSliderMidPressed, VSBSliderBtmPressed,
 		VSBSliderTopBg, VSBSliderMidBg, VSBSliderMidBgI, VSBSliderBtmBg,
                 HSBSliderTop, HSBSliderMid, HSBSliderBtm,
 		HSBSliderTopActive, HSBSliderMidActive, HSBSliderBtmActive,
-		HSBSliderTopHover, HSBSliderMidHover, HSBSliderBtmHover,
 		HSBSliderTopPressed, HSBSliderMidPressed, HSBSliderBtmPressed,
 		HSBSliderTopBg, HSBSliderMidBg, HSBSliderMidBgI, HSBSliderBtmBg,
 		Tab, TabDown, TabFocus, belowTab, belowTabDown,
 		ButtonShadow, CB, CBDown, CBTri, CBHover, CBDownHover, CBTriHover, CBPressed, CBDownPressed, CBTriPressed,
 		HSlider, VSlider, VSliderAbove, HSliderInactive, VSliderInactive, VSliderAboveInactive,
-		Progress, HTMLRadioOn, HTMLRadioOff,
-                HTMLRadioOnHover, HTMLRadioOffHover, HTMLCBDown, HTMLCBDownHover,
-                HTMLCBHover, HTMLCB,rectbutton, combo, comboShadow, progress2, TitleBar};
+		Progress, rectbutton, combo, comboShadow, progress2, TitleBar, BITMAP_ITEMS};
 
 enum CustomColor{CustomCBOn = 0, CustomCBOff, CustomRadioOn, CustomRadioOff,
                  CustomTabOn, CustomTabOff, CustomSBSlider, CustomSBSliderHover, CustomSBSliderPressed, CustomSBGroove};
@@ -69,7 +65,7 @@ enum myPosition{left = 0, center, right, full};
 
 enum tabStyle {TrueTab = 0, Clever, Chooser};
 
-enum Style {Jaguar = 0, Panther, Brushed, Tiger };
+enum Style {Jaguar = 0, Panther, Brushed, Tiger, Milk, NUMSTYLES };
 
 class ButtonTile
     {
@@ -150,10 +146,6 @@ public:
    {
       return ( bgStipple );
    }
-   inline static bool usePanelStipple()
-   {
-      return ( panelStipple );
-   }
    inline static Style style()
    {
       return (style_);
@@ -166,14 +158,6 @@ public:
    {
       return ( reverseBtnColor );
    }
-   inline static bool usePanelCustomColor()
-   {
-      return ( panelCustom );
-   }
-   inline QColor panelCustomColor()
-   {
-      return ( customPanelColor );
-   }
    inline static bool useToolButtonFrame()
    {
       return ( tbFrame );
@@ -278,9 +262,9 @@ public:
       return icyButtons;
    }
 
-   inline static bool ForceRectButton()
+   inline static Style buttonStyle()
    {
-      return forceRectButton;
+      return _buttonStyle;
    }
 
    inline static int ProgressBar()
@@ -293,9 +277,9 @@ public:
       return removeKickerBevel;
    }
 
-   inline static bool SmoothToolbuttons()
+   inline static Style toolbuttonStyle()
    {
-      return smoothToolbuttons;
+      return _toolbuttonStyle;
    }
 
    inline void setGroupShadowButton()
@@ -360,6 +344,10 @@ public:
    {
       return animateSlider;
    }
+   inline static bool AnimateProgress()
+   {
+      return animateProgress;
+   }
    inline static QColor CustomButtonColor()
    {
       return customButtonColor;
@@ -424,16 +412,13 @@ protected:
    //menu
    static bool useCustomMenuColor;
    static QColor color, color2, colorHigh, fgColor, fgColorHigh;
-   //Panel
-   static bool panelCustom;
-   static QColor customPanelColor;
    //incativeButton
    static int inactiveButtonColor;
    static QColor customInactiveButtonColor;
 
    //Design
    //stipples
-   static bool bgStipple, panelStipple, bevelHighlights_;
+   static bool bgStipple, bevelHighlights_;
    static Style style_;
    static int contrast;
    //shadows
@@ -454,23 +439,24 @@ protected:
    static bool smoothListViewHeaders;
    static bool smootherLVH;
    static bool icyButtons;
-   static bool forceRectButton;
+   static Style _buttonStyle;
    bool menusProcessed;
    bool scrollerActive;
    int menuLevelCounter;
    bool groupShadowButton;
    static int progressBar;
    static bool removeKickerBevel;
-   static bool smoothToolbuttons;
+   static Style _toolbuttonStyle;
    static bool drawProgressLabel;
    static tabStyle tabStyle_;
    
-   QString colorStr, fgColorStr, panelColorStr;
+   QString colorStr, fgColorStr/*, panelColorStr*/;
    static QColor brushTint;
    static QColor aDecoColor1_;
    static QColor aDecoColor2_;
    static bool tintBrush;
    static bool animateSlider;
+   static bool animateProgress;
 };
 	
 class EventKiller : public QObject 
@@ -555,8 +541,8 @@ protected:
    QImage* tintBrush( const QImage &img, const QColor &c ) const;
    QPixmap* processEmbedded( const char *label, const QColor &c, bool blend = false, const QColor *bg = NULL ) const;
    void drawRoundButton( QPainter *p, const QColorGroup &cg, const QColor &c, /*const QColor &bg,*/ int x, int y, int w, int h, bool pushedDown = false, bool hover = false, int bgX = -1, int bgY = -1) const;
-   void drawRectangularButton( QPainter *p, const QColorGroup &cg, const QColor &c, int x, int y, int w, int h, bool sunken = false, bool hover = false, bool isCombo = false, int position = full/*, bool isHtml = false*/) const;
-   void drawCombo( QPainter *painter, const QColorGroup &cg, const QColor &c, int x, int y, int w, int h, bool sunken, bool hover, bool isCombo, int position = full ) const;
+   void drawRectangularButton( QPainter *p, const QColorGroup &cg, const QColor &c, int x, int y, int w, int h, bool sunken = false, bool hover = false, bool isCombo = false, int position = full, bool isHtml = false) const;
+   void drawCombo( QPainter *painter, const QColorGroup &cg, const QColor &c, int x, int y, int w, int h, bool sunken, bool hover, bool isCombo, int position = full, bool isHTML = false ) const;
    void drawEditFrame( QPainter *p, const QRect &r, const QColorGroup &cg, bool isHTML = false, bool focused = false, bool inverse = false/*, bool round = false*/ ) const;
    void drawRoundFrame( QPainter *p, const QRect &r, const QColorGroup &cg, bool focused, QPoint offset ) const;
    void drawHTMLCBBorder( const QPixmap &pix, const QColor &c ) const;
@@ -580,8 +566,6 @@ private:
    QPixmap *btnBlendPix, *menuPix, *groupShadow ;
    QPixmap plainBrush, gradBrush;
    QBrush pagerBrush, pagerHoverBrush;
-   QBrush origPanelBrush;
-   QPalette origPanelPalette;
 
    QPixmap *pixmaps[ BITMAP_ITEMS ];
    QPixmap sbBuffer;
@@ -590,9 +574,9 @@ private:
    QWMatrix rMatrix;
    QWMatrix iMatrix;
    QWMatrix mMatrix;
+   QWMatrix m2Matrix;
 
    bool isKicker, isOOO, isHTMLButton, initialPaletteLoaded, inExitPolish;
-   QColor kickerColor;
 
    QHeader *currentHeader;
    QTabBar *currentTabBar;
@@ -636,10 +620,8 @@ private:
    QScrollBar *activeScroller;
    EventKiller *eventKiller;
    BMShower *bmShower;
-   QPixmap popupBack;
+   static QPixmap popupBack;
    QWidget *paintWidget;
-//    uint _htmlWidgetWId;
-
 };
 	
 #endif
