@@ -519,7 +519,7 @@ bool LiquidStyle::eventFilter( QObject *obj, QEvent *ev )
          return false;
       case QEvent::MouseButtonPress:
 //	 qWarning("class: %s, name: %s",obj->className(), obj->name());
-         if ( ::qt_cast<QToolBar*>(obj))
+      if ( optionHandler->style() > Panther && ::qt_cast<QToolBar*>(obj))
          {
             QMouseEvent *mev = (QMouseEvent *) ev;
             if (mev->button() != Qt::LeftButton)
@@ -663,6 +663,11 @@ bool LiquidStyle::eventFilter( QObject *obj, QEvent *ev )
                fadeIn((QPushButton*)obj);
             return false;
          }
+         if (::qt_cast<QProgressBar*>(obj))
+         {
+            progAnimWidgets[(QWidget*)obj] = 0;
+            return false;
+         }
          if ( !qstrcmp(obj->name(), "kde toolbar widget") )
          {
             QWidget* lb = static_cast<QWidget*>(obj);
@@ -716,6 +721,18 @@ bool LiquidStyle::eventFilter( QObject *obj, QEvent *ev )
                tb->removeEventFilter(eventKiller);
             }
          }
+         /*hmhmhmm... this may break qgroupbox children?!?*/
+         else if (::qt_cast<QGroupBox*>(obj))
+         {
+            QGroupBox* gb = (QGroupBox*)(obj);
+            if(gb->title().isEmpty()) return false;
+            QResizeEvent * e = (QResizeEvent*)ev;
+            int fm = gb->fontMetrics().height()+(gb->isCheckable()?4:1);
+            gb->setFrameRect(QRect(gb->rect().x(), gb->rect().y()+fm, e->size().width(), e->size().height()-fm/*-gb->frameWidth()*/));
+            if(gb->layout())
+               gb->layout()->setGeometry(QRect(gb->rect().x(), gb->rect().y(), e->size().width(), e->size().height()));
+            return true;
+         }
          else if ( obj->inherits( "KActiveLabel" ))
          {
             QWidget * w = ( QWidget * ) obj;
@@ -776,7 +793,7 @@ bool LiquidStyle::eventFilter( QObject *obj, QEvent *ev )
          {
             QWidget* widget = (QWidget*)obj;
             // create new brushpix
-            QPixmap tmpBrushPix(ev->type() == QEvent::Show?widget->width():rev->size().width(), 52);
+         QPixmap tmpBrushPix(ev->type() == QEvent::Show?widget->width():rev->size().width(), plainBrush.height());
             QPainter lightMe(&tmpBrushPix);
             // calc brush offsets
             int tmpWidth;
@@ -784,9 +801,9 @@ bool LiquidStyle::eventFilter( QObject *obj, QEvent *ev )
             {
                int leftWidth = (tmpWidth-1024)/2;
                int rightWidth = tmpWidth - leftWidth;
-               lightMe.drawTiledPixmap(0, 0, leftWidth, 52, plainBrush,256-leftWidth,0);
+               lightMe.drawTiledPixmap(0, 0, leftWidth, plainBrush.height(), plainBrush,256-leftWidth,0);
                lightMe.drawPixmap(leftWidth, 0, gradBrush);
-               lightMe.drawTiledPixmap(leftWidth + 1024, 0, rightWidth, 52, plainBrush);
+               lightMe.drawTiledPixmap(leftWidth + 1024, 0, rightWidth, plainBrush.height(), plainBrush);
             }
             else
                lightMe.drawPixmap(0, 0, gradBrush, (1024-tmpWidth)/2, 0, tmpWidth);
