@@ -36,22 +36,18 @@ const QColor& OptionHandler::textColor() {
 	}
 
 const QColor& OptionHandler::bgColor() {
-	LiquidStyle * style = ( LiquidStyle* ) parent();
-        return ( style->isKicker ? style->origPanelBrush.color() : qApp->palette().active().background() );
+   return qApp->palette().active().background();
 	}
 
 const QColor& OptionHandler::buttonColor() {
 	LiquidStyle * style = ( LiquidStyle* ) parent();
-	if (style->isKicker) return style->origPanelBrush.color();
-        else if (style->isOOO) return CustomButtonColor();
+	/*if (style->isKicker) return style->origPanelBrush.color();
+        else */if (style->isOOO) return CustomButtonColor();
         else return qApp->palette().active().button();
 	}
 
 void OptionHandler::reloadSettings() {
 	// gather options...
-	//QSettings *settings = new QSettings;
-//         KConfig *config = new KConfig("baghirarc");
-//         config.setGroup("Style");
         QSettings config;
         config.beginGroup("/baghira/Style");
 	//we need that first to make sure we use some proper settings ;)
@@ -60,72 +56,80 @@ void OptionHandler::reloadSettings() {
         // first try file:
         QString tmpString;
         FILE *file = NULL;
-        wmDesign = 4;
+        wmDesign = 5;
          for (int i = 0; i < 8; i++)
             custCols[i] = -1;
-        bool buttonsFollow, toolButtonsFollow;
-        buttonsFollow = config.readBoolEntry( "Design_ButtonsFollow", false);
-        toolButtonsFollow = config.readBoolEntry( "Design_ToolButtonsFollow", true);
         if (qstrcmp( qApp->argv() [ 0 ], "ksplash" ) == 0)
+        {
             style_ = Panther;
+            _toolbuttonStyle = Panther;
+            _buttonStyle = Panther;
+            tabStyle_ = Clever;
+            bgStipple = false;
+            inactiveButtonColor = Background;
+        }
         else
         {
         // first try for a tmp file from bab starter
-        tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + qApp->argv() [ 0 ];
-        if( (file = fopen(tmpString.latin1(), "r")) != NULL )
-            {
-            style_ = Panther;
-            fscanf(file,"%u\n%u\n",&style_, &wmDesign );
-            fclose (file);
-            smoothToolbuttons = toolButtonsFollow ? (style_ > Panther) ? false : true : config.readBoolEntry( "Special_RoundToolButtons", true);
-            forceRectButton = buttonsFollow ? (style_ == Brushed) ? true : false : config.readBoolEntry( "Design_RectangularButtons", false);
-            bgStipple = config.readBoolEntry( "Design_StippleBackground", true );
-            tabStyle_ = (tabStyle) config.readNumEntry( (style_ == Brushed)?"Design_TabStyleBrushed":"Design_TabStyleAqua", Clever);
-            remove(tmpString.latin1()); // remove TEMPORARY file
-            }
-        else
-        {
+         int tmpFile = 0;
+         tmpString = QDir::homeDirPath() + "/.baghira/.bab/" + qApp->argv() [ 0 ];
+         file = fopen(tmpString.latin1(), "r");
+         if( file == NULL )
+         {
+            tmpFile = 1;
             tmpString = QDir::homeDirPath() + "/.baghira/" + qApp->argv() [ 0 ];
-            if( (file = fopen(tmpString.latin1(), "r")) != NULL )
+            file = fopen(tmpString.latin1(), "r");
+            if( file == NULL )
             {
-               style_ = Panther; int i1 = -1; int i2 = -1; int i3 = -1; tabStyle_ = (tabStyle)-1;
-               fscanf(file,"%u\n%u\n%u\n%u\n%u\n%u\n%d\n%d\n%d\n%d\n%d\n%d\n%d\n%d\n",&style_, &wmDesign, &i1, &i2, &tabStyle_, &i3, &custCols[0], &custCols[1], &custCols[2], &custCols[3], &custCols[4], &custCols[5], &custCols[6], &custCols[7]);
-               fclose(file);
-               if (i2 == 0)
-                  smoothToolbuttons = TRUE;
-               else if (i2 == 1)
-                  smoothToolbuttons = FALSE;
-               else
-                  smoothToolbuttons = toolButtonsFollow ? (style_ > Panther) ? false : true : config.readBoolEntry( "Special_RoundToolButtons", true);
-               if (i1 == 0)
-                  forceRectButton = FALSE;
-               else if (i1 == 1)
-                  forceRectButton = TRUE;
-               else
-                  forceRectButton = buttonsFollow ? (style_ == Brushed) ? true : false : config.readBoolEntry( "Design_RectangularButtons", false);
-               if (tabStyle_ < 0 || tabStyle_ > 2)
-                  tabStyle_ = (tabStyle) config.readNumEntry( (style_ == Brushed)?"Design_TabStyleBrushed":"Design_TabStyleAqua", Clever);
-               if (style_ == Brushed)
-                  bgStipple = TRUE;
-               else if (i3 == 0)
-                  bgStipple = FALSE;
-               else if (i1 == 3)
-                  bgStipple = TRUE;
-               else
-                  bgStipple = config.readBoolEntry( "Design_StippleBackground", true );
+               tmpFile = 2;
+               tmpString = QDir::homeDirPath() + "/.baghira/.bab/.style";
+               file = fopen(tmpString.latin1(), "r");
             }
+         }
+         if (file != NULL)
+         {
+            style_ = _buttonStyle = _toolbuttonStyle = Panther; int i3 = inactiveButtonColor = -1; tabStyle_ = (tabStyle)-1;
+            fscanf(file,"%u\n%u\n%u\n%u\n%u\n%u\n%d\n%d\n%d\n%d\n%d\n%d\n%d\n%d\n%d\n",&style_, &wmDesign, &_buttonStyle, &_toolbuttonStyle, &tabStyle_, &i3, &custCols[0], &custCols[1], &custCols[2], &custCols[3], &custCols[4], &custCols[5], &custCols[6], &custCols[7], &inactiveButtonColor);
+            fclose(file);
+            if (_toolbuttonStyle < 0 || _toolbuttonStyle >= NUMSTYLES)
+               _toolbuttonStyle = (Style)config.readNumEntry( "Special_ToolbuttonStyle", style_);
+            if (_buttonStyle < 0 || _buttonStyle >= NUMSTYLES)
+               _buttonStyle = (Style)config.readNumEntry( "Special_ButtonStyle", style_);
+            if (tabStyle_ < 0 || tabStyle_ > 2)
+               tabStyle_ = (tabStyle) config.readNumEntry( (style_ == Brushed)?"Design_TabStyleBrushed":"Design_TabStyleAqua", Clever);
+            if (inactiveButtonColor < 0 || inactiveButtonColor > 3)
+               inactiveButtonColor = config.readNumEntry( "Design_InactiveButtonStyle", Background);
+            if (style_ == Brushed)
+               bgStipple = TRUE;
+            else if (i3 == 0)
+               bgStipple = FALSE;
             else
+               bgStipple = config.readBoolEntry( "Design_StippleBackground", true );
+            	// inactive Button
+            if (tmpFile == 0)
+               remove(tmpString.latin1()); // remove TEMPORARY file
+            else if (tmpFile == 2)
             {
-               style_ = (Style)config.readNumEntry( "Design_Default", Panther );
-            smoothToolbuttons = toolButtonsFollow ? (style_ > Panther) ? false : true : config.readBoolEntry( "Special_RoundToolButtons", true);
-            forceRectButton = buttonsFollow ? (style_ == Brushed) ? true : false : config.readBoolEntry( "Design_RectangularButtons", false);
+               tmpString = QDir::homeDirPath() + "/.baghira/.bab/.deco";
+               if ((file = fopen(tmpString.latin1(), "r")) != NULL)
+               {
+                  fscanf(file,"%u\n%u\n",&i3, &wmDesign);
+                  fclose(file);
+               }
+            }
+         }
+         else
+         {
+            style_ = (Style)config.readNumEntry( "Design_Default", Panther );
+            _toolbuttonStyle = (Style)config.readNumEntry( "Special_ToolbuttonStyle", style_);
+            _buttonStyle = (Style)config.readNumEntry( "Special_ButtonStyle", style_);
             tabStyle_ = (tabStyle) config.readNumEntry( (style_ == Brushed)?"Design_TabStyleBrushed":"Design_TabStyleAqua", Clever);
             bgStipple = (style_ == Brushed) ? true : config.readBoolEntry( "Design_StippleBackground", true );
-            }
-        }
+            inactiveButtonColor = config.readNumEntry( "Design_InactiveButtonStyle", Background);
+         }
         }
         contrast = 0;
-        if (wmDesign > 3)
+        if (wmDesign > 4)
            wmDesign = style_;
         if (style_ == Jaguar)
             contrast = 4;
@@ -176,17 +180,8 @@ void OptionHandler::reloadSettings() {
 		customColors[ CustomSBSliderPressed ].setRgb( config.readNumEntry( "Colors_SliderPressed", ( int ) buttonColor().dark(110).rgb() ) );
 		customColors[ CustomSBGroove ].setRgb( config.readNumEntry( "Colors_SliderGroove", ( int ) bgColor().rgb() ) );
 	}
-	// Panel
-	panelCustom = config.readBoolEntry( "Special_CustomKickerColor", false );
-	if (panelCustom)
-		customPanelColor = QColor( config.readNumEntry( "Special_KickerColor", ( int ) bgColor().rgb() ) );
-	// inactive Button
-	inactiveButtonColor = config.readNumEntry( "Design_InactiveButtonStyle", Background);
-	if (inactiveButtonColor == Custom)
-		customInactiveButtonColor = QColor( config.readNumEntry( "Design_InactiveButtonColor", (int) bgColor().rgb()));
-	//design stuff
-
-   panelStipple = (style_ == Brushed) ? true : config.readBoolEntry( "Special_StippleKicker", true );
+   if (inactiveButtonColor == Custom)
+      customInactiveButtonColor = QColor( config.readNumEntry( "Design_InactiveButtonColor", (int) bgColor().rgb()));
 	contrast += config.readNumEntry( "Design_StippleContrast", 3);
         bevelHighlights_ = config.readBoolEntry( "Design_BevelAsHighlight", true);
 	//shadows
@@ -212,12 +207,13 @@ groupboxshadow = (style_ == Brushed) ? false : config.readBoolEntry( "Design_Sha
 
 	// tweaks
 	centerTabs = config.readBoolEntry( "Design_CenterTabs", true);
-	smoothListViewHeaders = !config.readBoolEntry( "Special_UseFlatLVH", false);
+	smoothListViewHeaders = (style_ == Milk) ? true : !config.readBoolEntry( "Special_UseFlatLVH", false);
 	smootherLVH = config.readBoolEntry( "Special_RoundTaskbuttons", false);
 	icyButtons = config.readNumEntry( "Design_ButtonStyle", 0) == 0;
 	progressBar = config.readNumEntry( "Special_ProgressStyle", baghira);
 	removeKickerBevel = config.readBoolEntry( "Special_RemoveKickerBevel", false);
-   animateButton = config.readBoolEntry( "Design_AnimateButtons", true);
+         animateButton = config.readBoolEntry( "Design_AnimateButtons", true);
+      animateProgress = config.readBoolEntry( "Design_AnimateProgress", true);
 	drawProgressLabel = config.readBoolEntry( "Special_ShowProgressValue", false);
    config.endGroup();
    
