@@ -30,6 +30,7 @@
 #include <qtabbar.h>
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
+#include <kdeversion.h>
 #include <kpixmapeffect.h>
 #include <kglobalsettings.h>
 #include <kwin.h>
@@ -47,67 +48,49 @@ x > u ? u :\
 x
 #endif
 
-/*
-Internal class to get access to protected QWidget-members
-*/
 
-class QAccessMenu : public QMenuBar
+void LiquidStyle::polish( QPalette &pal )
 {
-    friend class LiquidStyle;
-    public:
-        QAccessMenu( QWidget* parent=0, const char* name=0 )
-    : QMenuBar( parent, name ) {}
-};
+   if ( inExitPolish )
+      return ;
+   // clear out all old colorized pixmaps
+   int i;
+   for ( i = 0; i < BITMAP_ITEMS; ++i )
+   {
+      if ( pixmaps[ i ] )
+      {
+         delete pixmaps[ i ];
+         pixmaps[ i ] = NULL;
+      }
+   }
+   // clear out all dicts
+   btnDict.clear();
+   btnShadowedDict.clear();
+   // reset brushes
+   pagerHoverBrush = QBrush();
+   pagerBrush = QBrush();
 
-void LiquidStyle::polish( QPalette &pal ) {
-    if ( inExitPolish )
-            return ;
-    // clear out all old colorized pixmaps
-    int i;
-    for ( i = 0; i < BITMAP_ITEMS; ++i ) {
-            if ( pixmaps[ i ] ) {
-                    delete pixmaps[ i ];
-                    pixmaps[ i ] = NULL;
-                    }
-            }
-    // clear out all dicts
-    btnDict.clear();
-    btnShadowedDict.clear();
-    // reset brushes
-    pagerHoverBrush = QBrush();
-    pagerBrush = QBrush();
+   bool newPalette = false;
+   struct stat buffer;
+   if ( stat( QFile::encodeName( QDir::homeDirPath() + "/.qt/qtrc" ), &buffer ) == 0 )
+   {
+      unsigned int lastModTime = ( unsigned int ) buffer.st_mtime;
+      if ( lastModTime > qtrcModificationTime )
+      {
+         qtrcModificationTime = lastModTime;
+         newPalette = true;
+      }
+   }
+   else if ( !initialPaletteLoaded )  // Hack, should always have qtrc in KDE
+      newPalette = true;
+   initialPaletteLoaded = true;
 
-    /**
-    * Okay, here's the deal. We might need to set the application
-    * background brush with a pixmap stipple or a custom kicker color.
-    * It wouldn't be much of a problem but Qt calls this method for a lot
-    * of different palettes, not just the application's, so we really don't
-    * know what we are changing and if the QPalette parameter is actually
-    * the application's colors or something like a tooltip.
-    *
-    * This used to mean I'd check the timestamp of .qt/qtrc and reload the
-    * entire palette if it has changed. Now we just assume the QPalette
-    * parameter is the new application palette. Much more efficent :)
-    */
+   if ( !newPalette )
+   {
+      pal = polishedPalette;
+      return ;
+   }
 
-    bool newPalette = false;
-    struct stat buffer;
-    if ( stat( QFile::encodeName( QDir::homeDirPath() + "/.qt/qtrc" ), &buffer ) == 0 ) {
-        unsigned int lastModTime = ( unsigned int ) buffer.st_mtime;
-        if ( lastModTime > qtrcModificationTime ) {
-            qtrcModificationTime = lastModTime;
-            newPalette = true;
-        }
-    }
-    else if ( !initialPaletteLoaded )  // Hack, should always have qtrc in KDE
-        newPalette = true;
-    initialPaletteLoaded = true;
-
-    if ( !newPalette ) {
-        pal = polishedPalette;
-        return ;
-    }
-        
    originalBgColor = pal.color(QPalette::Active, QColorGroup::Background);
    if (optionHandler->style() == Brushed)
       pal.setColor(QColorGroup::Background, brushedMetalColor(optionHandler->BrushTint()));
@@ -118,130 +101,129 @@ void LiquidStyle::polish( QPalette &pal ) {
       pal.setColor(QColorGroup::Background, QColor(optionHandler->custCols[0]));
       pal.setColor(QColorGroup::Button, QColor(optionHandler->custCols[1]));
       pal.setColor(QColorGroup::Base, QColor(optionHandler->custCols[2]));
-      pal.setColor(QColorGroup::Text, QColor(optionHandler->custCols[3]));
+      pal.setColor(QPalette::Active, QColorGroup::Text, QColor(optionHandler->custCols[3]));
+      pal.setColor(QPalette::Active, QColorGroup::Foreground, QColor(optionHandler->custCols[3]));
       pal.setColor(QColorGroup::Highlight, QColor(optionHandler->custCols[4]));
-      pal.setColor(QColorGroup::HighlightedText, QColor(optionHandler->custCols[5]));
-      pal.setColor(QColorGroup::ButtonText, QColor(optionHandler->custCols[6]));
+      pal.setColor(QPalette::Active, QColorGroup::HighlightedText, QColor(optionHandler->custCols[5]));
+      pal.setColor(QPalette::Active, QColorGroup::ButtonText, QColor(optionHandler->custCols[6]));
+      pal.setColor(QColorGroup::Mid, QColor((qRed(optionHandler->custCols[2])+qRed(optionHandler->custCols[3]))/2,(qGreen(optionHandler->custCols[2])+qGreen(optionHandler->custCols[3]))/2,(qBlue(optionHandler->custCols[2])+qBlue(optionHandler->custCols[3]))/2));
+      
+      pal.setColor(QPalette::Inactive, QColorGroup::Text, QColor(optionHandler->custCols[3]));
+      pal.setColor(QPalette::Inactive, QColorGroup::HighlightedText, QColor(optionHandler->custCols[5]));
+      pal.setColor(QPalette::Inactive, QColorGroup::ButtonText, QColor(optionHandler->custCols[6]));
    }
    else
       pal.setColor( QColorGroup::Button, optionHandler->CustomButtonColor() );
+#if 0
+   if ( isKicker )
+   {
+      origPanelBrush = pal.brush( QPalette::Active, QColorGroup::Background );
+      origPanelPalette = pal;
+      QColor c( pal.active().background() );
+      
+      if ( optionHandler->usePanelCustomColor() && optionHandler->panelCustomColor().isValid() )
+         c = optionHandler->panelCustomColor();
+      
+      kickerColor = c;
 
-    // only executed on first run or if qtrc has changed
-    if ( isKicker ) {
-        origPanelBrush = pal.brush( QPalette::Active, QColorGroup::Background );
-        origPanelPalette = pal;
-        QColor c( pal.active().background() );
-        if ( optionHandler->usePanelCustomColor() && optionHandler->panelCustomColor().isValid() ){
-            c = optionHandler->panelCustomColor();
-        }
-        kickerColor = c;
+      pal.setColor( QColorGroup::Mid, optionHandler->CustomButtonColor().dark( 110 ) );
+      pal.setColor( QColorGroup::Dark, optionHandler->CustomButtonColor().dark( 130 ) );
+      pal.setColor( QColorGroup::Midlight, optionHandler->CustomButtonColor().light( 110 ) );
+      pal.setColor( QColorGroup::Light, optionHandler->CustomButtonColor().light( 115 ) );
+      pal.setColor( QColorGroup::Button, optionHandler->CustomButtonColor());
 
-        pal.setColor( QColorGroup::Mid, optionHandler->CustomButtonColor().dark( 110 ) );
-        pal.setColor( QColorGroup::Dark, optionHandler->CustomButtonColor().dark( 130 ) );
-        pal.setColor( QColorGroup::Midlight, optionHandler->CustomButtonColor().light( 110 ) );
-        pal.setColor( QColorGroup::Light, optionHandler->CustomButtonColor().light( 115 ) );
-        pal.setColor( QColorGroup::Button, optionHandler->CustomButtonColor());
-        
-       if (optionHandler->style() == Brushed){
-            QBrush brush( c, gradBrush );
-            pal.setBrush( QColorGroup::Background, brush );
-        }
-        else if ( optionHandler->usePanelStipple() ) {
-            QPixmap stipple( 64, 64 );
-            stipple.fill( c.rgb() );
-            QPainter p;
-            p.begin( &stipple );
-            p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/2) ) );
-            for ( i = 1; i < 64; i += 4 ) {
-                p.drawLine( 0, i, 63, i );
-                p.drawLine( 0, i+2, 63, i+2 );
-                }
-            p.setPen( c.dark( 100 + optionHandler->stippleContrast() ) );
-            for ( i = 2; i < 63; i += 4 ) {
-                p.drawLine( 0, i, 63, i );
-                }
-            p.end();
-            QBrush brush( c, stipple );
-                pal.setBrush( QColorGroup::Background, brush );
-        }
-        else
-            pal.setBrush( QColorGroup::Background, c );
-    }
-   else if (optionHandler->style() == Brushed){
-        QColor c( pal.active().background() );
-        QBrush brush( c, gradBrush );
-        pal.setBrush( QColorGroup::Background, brush );
-    }
-    else if ( !isPlain() ) {
-        origPanelBrush = pal.brush( QPalette::Active,QColorGroup::Button );
-        QColor c( pal.active().background() );
-        QPixmap stipple( 64, 64 );
-        stipple.fill( c.rgb() );
-        QPainter p;
-        p.begin( &stipple );
-        p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/2) ) );
-        for ( i = 1; i < 64; i += 4 ) {
+      if (optionHandler->style() == Brushed)
+      {
+         QBrush brush( c, gradBrush );
+         pal.setBrush( QColorGroup::Background, brush );
+      }
+      else if ( optionHandler->usePanelStipple() )
+      {
+         QPixmap stipple( 64, 64 );
+         stipple.fill( c.rgb() );
+         QPainter p( &stipple );
+         p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/4) ) );
+         for ( int i = 1; i < 64; i += 4 )
+         {
             p.drawLine( 0, i, 63, i );
             p.drawLine( 0, i+2, 63, i+2 );
-        }
-        p.setPen( c.dark( 100 + optionHandler->stippleContrast() ) );
-        for ( i = 2; i < 63; i += 4 ) {
+         }
+         p.setPen( c.dark( 100 + optionHandler->stippleContrast()) );
+         for ( int i = 2; i < 63; i += 4 )
             p.drawLine( 0, i, 63, i );
-        }
-        p.end();
-        QBrush brush( c, stipple );
-        pal.setBrush( QColorGroup::Background, brush );
-    }
+         p.end();
+         QBrush brush( c, stipple );
+         pal.setBrush( QColorGroup::Background, brush );
+      }
+      else
+         pal.setBrush( QColorGroup::Background, c );
+   }
+#endif
+   /*else*/ if (optionHandler->style() == Brushed)
+   {
+      QColor c( pal.active().background() );
+      QBrush brush( c, gradBrush );
+      pal.setBrush( QColorGroup::Background, brush );
+   }
+   else if ( !isPlain() )
+   {
+      QColor c( pal.active().background() );
+      QPixmap stipple( 64, 64 );
+      stipple.fill( c.rgb() );
+      QPainter p;
+      p.begin( &stipple );
+      p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/2) ) );
+      for ( i = 1; i < 64; i += 4 )
+      {
+         p.drawLine( 0, i, 63, i );
+         p.drawLine( 0, i+2, 63, i+2 );
+      }
+      p.setPen( c.dark( 100 + optionHandler->stippleContrast() ) );
+      for ( i = 2; i < 63; i += 4 )
+         p.drawLine( 0, i, 63, i );
+      p.end();
+      QBrush brush( c, stipple );
+      pal.setBrush( QColorGroup::Background, brush );
+   }
     
-    if (optionHandler->bevelHighlights()){
-        QColor c(pal.active().highlight());
-        QColor c2(c.light(140));
-        QPixmap pix2 = QPixmap(48,48);
-        QPainter coolPainter(&pix2);
-        KPixmap pix = QPixmap(48,24);
-        KPixmapEffect::gradient(pix,c,c2,KPixmapEffect::VerticalGradient,0);
-        coolPainter.drawPixmap(0,0,pix);
-        KPixmapEffect::gradient(pix,c2,c,KPixmapEffect::VerticalGradient,0);
-        coolPainter.drawPixmap(0,24,pix);
-        QBrush brush(c, pix2);
-        pal.setBrush(QColorGroup::Highlight, brush);
-    }
-    polishedPalette = pal;
-    optionHandler->reset();
-    }
+   if (optionHandler->bevelHighlights())
+   {
+      QColor c(pal.active().highlight());
+      QColor c2(c.light(140));
+      QPixmap pix2 = QPixmap(48,48);
+      QPainter coolPainter(&pix2);
+      KPixmap pix = QPixmap(48,24);
+      KPixmapEffect::gradient(pix,c,c2,KPixmapEffect::VerticalGradient,0);
+      coolPainter.drawPixmap(0,0,pix);
+      KPixmapEffect::gradient(pix,c2,c,KPixmapEffect::VerticalGradient,0);
+      coolPainter.drawPixmap(0,24,pix);
+      QBrush brush(c, pix2);
+      pal.setBrush(QColorGroup::Highlight, brush);
+   }
+   polishedPalette = pal;
+   optionHandler->reset();
+}
 
-void LiquidStyle::unPolish( QApplication *app ) {
-
-    popupBack.resize(0,0);
-    QPalette pal( app->palette() );
-    inExitPolish = true;
-    if ( isKicker )
-    {
-        // reset kicker
-        QColor c = origPanelBrush.color();
-        pal.setBrush( QColorGroup::Background, c );
-        pal.setBrush( QColorGroup::Mid, c.dark( 110 ) );
-        pal.setBrush( QColorGroup::Dark, c.dark( 130 ) );
-        pal.setBrush( QColorGroup::Midlight, c.light( 110 ) );
-        pal.setBrush( QColorGroup::Light, c.light( 115 ) );
-//         app->blockSignals( TRUE );
-        app->setPalette( pal );
-//         app->blockSignals( FALSE );
-        }
-        else if ( !isPlain() )
-        {
-            // reset any stipples
-            if ( pal.brush( QPalette::Active, QColorGroup::Background ).pixmap() )
-                    pal.setBrush( QColorGroup::Background, pal.active().background() );
-            if ( pal.brush( QPalette::Active, QColorGroup::Button ).pixmap() )
-                    pal.setBrush( QColorGroup::Button, pal.active().button() );
+void LiquidStyle::unPolish( QApplication *app )
+{
+   popupBack.resize(0,0);
+   QPalette pal( app->palette() );
+   inExitPolish = true;
+   
+   if ( !isPlain() )
+   {
+      // reset any stipples
+      if ( pal.brush( QPalette::Active, QColorGroup::Background ).pixmap() )
+         pal.setBrush( QColorGroup::Background, pal.active().background() );
+      if ( pal.brush( QPalette::Active, QColorGroup::Button ).pixmap() )
+         pal.setBrush( QColorGroup::Button, pal.active().button() );
 //             app->blockSignals( TRUE );
-            app->setPalette( pal );
+      app->setPalette( pal );
 //             app->blockSignals( FALSE );
-        }
+   }
 
-        inExitPolish = false;
-        }
+   inExitPolish = false;
+}
 
 Atom baghira_deco_design = XInternAtom(qt_xdisplay(), "BAGHIRA_DECO_DESIGN", False);
 
@@ -264,24 +246,16 @@ void LiquidStyle::polish( QWidget *w )
     {
         if ( ::qt_cast<QPopupMenu*>(w)) // popup menu designs
         {
-            w->setBackgroundMode( QWidget::PaletteBackground );
-            if (optionHandler->UseCustomMenuColor())
-            {
-                QPalette pal( w->palette() );
-                pal.setBrush( QColorGroup::Highlight, optionHandler->menuColorHigh() );
-                pal.setBrush( QColorGroup::HighlightedText, optionHandler->textColorHigh() );
-                w->setPalette( pal );
-            }
             switch (optionHandler->MenuBackground())
             {
             case Plain:
-                if (optionHandler->UseCustomMenuColor())
-                    w->setPaletteBackgroundColor(optionHandler->Color());
-                else if (optionHandler->MenuColorButton())
-                    w->setPaletteBackgroundColor(optionHandler->buttonColor());
-                else
-                    w->setPaletteBackgroundColor(optionHandler->bgColor());
-//                 w->setBackgroundMode( QWidget::NoBackground );
+               w->setBackgroundMode( QWidget::PaletteBackground );
+               if (optionHandler->UseCustomMenuColor())
+                  w->setPaletteBackgroundColor(optionHandler->Color());
+               else if (optionHandler->MenuColorButton())
+                  w->setPaletteBackgroundColor(optionHandler->buttonColor());
+               else
+                  w->setPaletteBackgroundColor(optionHandler->bgColor());
                 break;
             case Stipples:
             {
@@ -302,9 +276,9 @@ void LiquidStyle::polish( QWidget *w )
                     if (optionHandler->UseCustomMenuColor())
                     {
                         QColor c2 = QColor( optionHandler->Color2() );
-                        p.setPen(QColor((c.red()+2*c2.red())/3,
-                                        (c.green()+2*c2.green())/3,
-                                        (c.blue()+2*c2.blue())/3));
+                        p.setPen(QColor((3*c.red()+c2.red())/4,
+                                        (3*c.green()+c2.green())/4,
+                                        (3*c.blue()+c2.blue())/4));
                         for ( int i = 1; i < 64; i += 4 )
                         {
                             p.drawLine( 0, i, 63, i );
@@ -318,7 +292,7 @@ void LiquidStyle::polish( QWidget *w )
                     }
                     else
                     {
-                        p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/2) ) );
+                        p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/4) ) );
                         for ( int i = 1; i < 64; i += 4 )
                         {
                             p.drawLine( 0, i, 63, i );
@@ -332,20 +306,20 @@ void LiquidStyle::polish( QWidget *w )
                     }
                     p.end();
                 }
-//                 w->setPaletteBackgroundPixmap(stipple);
                 w->setBackgroundMode( QWidget::NoBackground );
                 break;
             }
             case Gradient:
             {
-                KPixmap tmpPix = QPixmap(w->width(), 32);
-                w->setPaletteBackgroundPixmap(KPixmapEffect::unbalancedGradient(tmpPix, optionHandler->Color(), optionHandler->Color2(),KPixmapEffect::HorizontalGradient, 100, 100, 16));
-                w->installEventFilter( this );
-//                 w->setBackgroundMode( QWidget::NoBackground );
-                break;
+               w->setBackgroundMode( QWidget::PaletteBackground );
+               KPixmap tmpPix = QPixmap(w->width(), 32);
+               w->setPaletteBackgroundPixmap(KPixmapEffect::unbalancedGradient(tmpPix, optionHandler->Color(), optionHandler->Color2(),KPixmapEffect::HorizontalGradient, 100, 100, 16));
+               w->installEventFilter( this );
+               break;
             }
             default:
-                break;
+               w->setBackgroundMode( QWidget::PaletteBackground );
+               break;
             }
             //set popup menu opacity for them as they bypass the windowmanager
             unsigned long opacity = optionHandler->MenuOpacity()/100.0*OPAQUE;
@@ -354,7 +328,7 @@ void LiquidStyle::polish( QWidget *w )
         }
         else
         {
-            if (optionHandler->wmDesign < 4) // set deco design X Property
+            if (optionHandler->wmDesign < 5) // set deco design X Property
             {
                unsigned char *data = 0;
                Atom actual;
@@ -363,7 +337,7 @@ void LiquidStyle::polish( QWidget *w )
                result = XGetWindowProperty(qt_xdisplay(), w->winId(), baghira_deco_design, 0L, 1L, False, XA_CARDINAL, &actual, &format, &n, &left, &data);
                if (result != Success || data == None) // not found set design
                {
-            int tmp = optionHandler->wmDesign < Tiger ? optionHandler->wmDesign : Panther;
+            int tmp = optionHandler->wmDesign != Tiger ? optionHandler->wmDesign : Panther;
                   XChangeProperty(qt_xdisplay(), w->winId(), baghira_deco_design, XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &(tmp), 1L);
                }
             }
@@ -410,14 +384,6 @@ void LiquidStyle::polish( QWidget *w )
         w->setBackgroundOrigin(QWidget::WindowOrigin);
         if (::qt_cast<QPushButton*>(w))
         {
-//             if (isViewportChild)
-//             {
-//                 w->setAutoMask( false );
-//                w->setBackgroundMode( Qt::X11ParentRelative );
-//                 w->setBackgroundMode( QWidget::NoBackground );
-//                w->installEventFilter( this );
-//                 goto kstpolish;
-//             }
            if (w->inherits("KKeyButton"))
            {
               w->setBackgroundMode( QWidget::PaletteBackground);
@@ -432,7 +398,10 @@ void LiquidStyle::polish( QWidget *w )
               pal.setBrush( QColorGroup::Background, qApp->palette().brush(QPalette::Active, QColorGroup::Background));
               w->setPalette( pal );
            }
-            else //if (!(w->parent() && w->parent()->inherits("MiniBar")))
+            else
+#if !KDE_IS_VERSION(3,4,3)
+	    if (!(w->parent() && w->parent()->inherits("MiniBar")))
+#endif
                 w->setBackgroundMode( QWidget::NoBackground);
             w->installEventFilter( this );
             goto kstpolish;
@@ -441,12 +410,6 @@ void LiquidStyle::polish( QWidget *w )
          {
             w->setBackgroundOrigin(QWidget::WindowOrigin);
             w->installEventFilter( this );
-//             if (isViewportChild)
-//             {
-//                w->setMask(getPixmap( HTMLRadioOff)->mask());
-//                w->setAutoMask( TRUE );
-//                w->setBackgroundMode( QWidget::NoBackground );
-//             }
             goto kstpolish;
          }
     }
@@ -485,8 +448,6 @@ void LiquidStyle::polish( QWidget *w )
 	
     if (::qt_cast<QComboBox*>(w))
     {
-//         if (isViewportChild)
-//             w->setAutoMask( TRUE );
         w->setBackgroundMode(NoBackground);
         w->installEventFilter( this );
         w->setBackgroundOrigin(QWidget::WindowOrigin);
@@ -586,9 +547,9 @@ void LiquidStyle::polish( QWidget *w )
     if (w->inherits( "KickerTip" ))
         // kickers new tooltip uses backgroundColor() instead of paletteBackgroundColor() - causing Qt::black
     {
-        w->setPaletteBackgroundColor(kickerColor);
-        w->setBackgroundMode( QWidget::NoBackground );
-        goto kstpolish;
+      w->setPaletteBackgroundColor(qApp->palette().color(QPalette::Active, QColorGroup::Button));
+      w->setBackgroundMode( QWidget::NoBackground );
+      goto kstpolish;
     }
 
     if ( !isPlain() ) 
@@ -636,6 +597,13 @@ void LiquidStyle::polish( QWidget *w )
 //                 w->setErasePixmap(stipple);
 //             }
         w->setBackgroundMode( QWidget::PaletteBackground );
+       if (optionHandler->UseCustomMenuColor())
+       {
+          QPalette pal( w->palette() );
+          pal.setBrush( QColorGroup::Highlight, optionHandler->menuColorHigh() );
+          pal.setBrush( QColorGroup::HighlightedText, optionHandler->textColorHigh() );
+          w->setPalette( pal );
+       }
         w->setBackgroundOrigin(QWidget::WindowOrigin);
         w->installEventFilter( this );
 #if 0
@@ -655,22 +623,6 @@ void LiquidStyle::polish( QWidget *w )
            if (overline)
               (const_cast<QFont*>(&w->font()))->setOverline(true);
         }
-#endif
-#if 0
-// try to make maclike qmenubars as well - currently deactivated, as i'd need to reimplement the drawcontents function - best was if TT just'd c&p the KDE code
-        {
-            QAccessMenu* am = ((QAccessMenu*)w);
-            am->setBackgroundMode(QWidget::X11ParentRelative);
-            am->setBackgroundOrigin(QWidget::WindowOrigin);
-            am->reparent( am->parentWidget(), WType_TopLevel | WStyle_Tool | WStyle_Customize | WStyle_NoBorder, QPoint(0,0), false );
-            KWin::setType( am->winId(), NET::TopMenu );
-            if( am->parentWidget())
-                XSetTransientForHint( qt_xdisplay(), am->winId(), am->parentWidget()->topLevelWidget()->winId());
-            am->setFrameStyle( QFrame::NoFrame );
-            am->setLineWidth( 0 );
-            am->setMargin( 0 );
-            am->erase();
-        }
 #endif
         goto kstpolish ;
     }
@@ -711,21 +663,6 @@ void LiquidStyle::polish( QWidget *w )
             w->installEventFilter( this ); // the widget resets it's frameshape on mouseevents - looks crap!
             goto kstpolish ;
         }
-#if 0
-                else if (!optionHandler->BrushMe() && w->inherits("MenubarExtension")){
-                    QImage img = KImageEffect::unbalancedGradient(QSize(48,w->height()),Qt::white,Qt::black,KImageEffect::VerticalGradient,0,110);
-                    QPixmap pix = QPixmap(48,w->height());
-                    QPainter p;
-                    p.begin(&pix);
-                    w->paletteBackgroundPixmap()?p.drawTiledPixmap(0,0,48,w->height(),*w->paletteBackgroundPixmap()):p.fillRect(0,0,48,w->height(),w->paletteBackgroundColor());
-                    p.end();
-                    QImage img2 = pix.convertToImage();
-                    img = KImageEffect::blend(img2,img,0.3);
-                    w->setPaletteBackgroundPixmap(img);
-                    ((QFrame *)w)->setFrameShape(QFrame::NoFrame);
-                    goto kstpolish;
-                }
-#endif
                 else if (((QFrame *)w)->frameShape() >= QFrame::Box && ((QFrame *)w)->frameShape() <= QFrame::WinPanel){
 			((QFrame *)w)->setFrameShape(QFrame::StyledPanel);
                         goto kstpolish ;
@@ -762,41 +699,30 @@ void LiquidStyle::polish( QWidget *w )
 		goto kstpolish;
 	}
         
-        if (::qt_cast<QGroupBox*>(w) && ((QGroupBox*)w)->frameShape() == QFrame::GroupBoxPanel && !((QGroupBox*)w)->isFlat()){
-            if ( optionHandler->drawGroupBoxShadow() ){
-            if ( isKicker ){ // kicker (and children) needs special handling again - otherwise the shadow pixmap won't be found and your GB will be completely black
-                this->groupShadow = new QPixmap( 64, 64 );
-                QColor c;
-                ( optionHandler->MenuColorButton() ) ? c = QColor( optionHandler->buttonColor() ) : c = QColor( optionHandler->bgColor() );
-                this->groupShadow->fill( ( c.dark( 100 + optionHandler->ShadowDarkness() ) ).rgb() );
-                if ( optionHandler->useBgStipple() ) {
-                    QPainter p;
-                    p.begin( this->groupShadow );
-                    p.setPen( c.dark( 100 + optionHandler->ShadowDarkness() + (int)(optionHandler->stippleContrast()/2) ) );
-                    for ( int i = 1; i < 64; i += 4 ) {
-                        p.drawLine( 0, i, 63, i );
-                        p.drawLine( 0, i+2, 63, i+2 );
-                    }
-                    p.setPen( c.dark( 100 + optionHandler->ShadowDarkness() + optionHandler->stippleContrast() ) );
-                    for ( int i = 2; i < 63; i += 4 ) {
-                            p.drawLine( 0, i, 63, i );
-                            }
-                }
-                w->setPaletteBackgroundPixmap ( *(this->groupShadow) );
-            }
-            else{
-                w->setPaletteBackgroundPixmap ( *groupShadow );
-            }
-            }
-            w->setBackgroundOrigin(QWidget::WindowOrigin);
-        }
-        //if (testWidget) qWarning("testwidget stage %d",testInt++);
+   if (::qt_cast<QGroupBox*>(w) && ((QGroupBox*)w)->frameShape() == QFrame::GroupBoxPanel && !((QGroupBox*)w)->isFlat())
+   {
+      if ( optionHandler->drawGroupBoxShadow() )
+      {
+            w->setPaletteBackgroundPixmap ( *groupShadow );
+         if (((QGroupBox*)w)->isCheckable())
+         {
+            QWidget *cb = (QWidget*)w->child("qt_groupbox_checkbox",0,false);
+            cb->setPalette(w->parentWidget() ? w->parentWidget()->palette() : qApp->palette());
+            QFont font( cb->font() );
+            font.setBold( true );
+            cb->setFont( font );
+         }
+      }
+      w->setBackgroundOrigin(QWidget::WindowOrigin);
+      w->installEventFilter(this);
+   }
+   //if (testWidget) qWarning("testwidget stage %d",testInt++);
 
 
 	if (w->inherits("QProgressBar"))
 	{
 		w->setBackgroundMode( NoBackground );
-                progAnimWidgets[w] = 0;
+               w->installEventFilter(this);
                 connect(w, SIGNAL(destroyed(QObject*)), this, SLOT(progressBarDestroyed(QObject*)));
 		goto kstpolish;
 	}
@@ -818,46 +744,9 @@ void LiquidStyle::polish( QWidget *w )
         if ( w->inherits( "KdetvView")) {
             w->setBackgroundMode( QWidget::NoBackground );
         }
-        //if (testWidget) qWarning("testwidget stage %d",testInt++);
-
-	if ( w->isTopLevel() && isKicker ) {
-	// more kicker stuff
-		// force extensions and child panels to use proper palette.
-		if ( !w->inherits( "Panel" ) && !w->inherits( "KPanelApplet" ) ) {
-			if (!origPanelPalette.active().brush( QColorGroup::Background ).pixmap() ) {
-   			if ((optionHandler->style() == Brushed)) {
-					QBrush brush( origPanelPalette.active().brush( QColorGroup::Background ) );
-//					QPixmap brushed = optionHandler->TintBrush() ? *tintBrush(fetchImage( "brush-me" ), optionHandler->BrushTint()) : fetchImage("brush-me" );
-					brush.setPixmap( gradBrush );
-					origPanelPalette.setBrush( QColorGroup::Background, brush );
-				} else if ( !isPlain()) {
-				QBrush brush( origPanelPalette.active().brush( QColorGroup::Background ) );
-				QColor c( brush.color() );
-				QPixmap stipple( 64, 64 );
-				stipple.fill( c.rgb() );
-				QPainter p;
-				p.begin( &stipple );
-				p.setPen( c.dark( 100 + (int)(optionHandler->stippleContrast()/2) ) );
-				for ( int i = 1; i < 64; i += 4 ) {
-					p.drawLine( 0, i, 63, i );
-					p.drawLine( 0, i+2, 63, i+2 );
-				}
-                                p.setPen( c.dark( 100 + optionHandler->stippleContrast()) );
-                                for ( int i = 2; i < 63; i += 4 ) {
-                                        p.drawLine( 0, i, 63, i );
-                                        }
-				p.end();
-				brush.setPixmap( stipple );
-				origPanelPalette.setBrush( QColorGroup::Background, brush );
-			}
-                        }
-			w->setPalette( origPanelPalette );
-		}
-		goto kstpolish ;
-	}
-        //if (testWidget) qWarning("testwidget stage %d",testInt++);
-kstpolish:	KStyle::polish( w ); // nothing of all above? do default kde stuff
-	}
+   //if (testWidget) qWarning("testwidget stage %d",testInt++);
+   kstpolish:	KStyle::polish( w ); // nothing of all above? do default kde stuff
+}
 
 
 
@@ -871,7 +760,6 @@ void LiquidStyle::unPolish( QWidget *w ) {
         
 
 	if (w->inherits("KColorGrid")){
-//             w->setBackgroundMode(QWidget::PaletteBackground);
             goto kstunpolish;
         }
         
@@ -953,12 +841,6 @@ void LiquidStyle::unPolish( QWidget *w ) {
 		goto kstunpolish;
 		}
 
-	if ( w->isTopLevel() && isKicker && !w->inherits( "Panel" ) &&
-	        !w->inherits( "KPanelApplet" ) ) {
-		w->unsetPalette();
-		goto kstunpolish;
-		}
-
 	isViewport = qstrcmp( w->name(), "qt_viewport" ) == 0 ||
 	                  qstrcmp( w->name(), "qt_clipped_viewport" ) == 0;
 	isViewportChild = w->parent() &&
@@ -968,7 +850,6 @@ void LiquidStyle::unPolish( QWidget *w ) {
 	if ( isViewportChild ) {
 		if ( w->inherits( "QRadioButton" ) || w->inherits( "QComboBox" ) || w->inherits( "QPushButton" ) ) {
 			if ( isHTMLWidget( w ) ) {
-				w->setAutoMask( FALSE );
 				w->setBackgroundMode( QWidget::PaletteBackground );
 				goto kstunpolish;
 				}
